@@ -12,6 +12,10 @@
 # option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
 # the full text of the license.
 
+# pylint: disable=too-many-lines
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import base64
 import datetime
 import glob
@@ -26,6 +30,7 @@ import tempfile
 
 import apport.fileutils
 from apport.packaging_impl import impl as packaging
+from problem_report import ProblemReport
 
 _invalid_key_chars_re = re.compile(r"[^0-9a-zA-Z_.-]")
 _AGENT = None
@@ -41,9 +46,7 @@ def path_to_key(path):
     return _invalid_key_chars_re.sub(".", path.replace(" ", "_"))
 
 
-def attach_file_if_exists(
-    report, path, key=None, overwrite=True, force_unicode=False
-):
+def attach_file_if_exists(report, path, key=None, overwrite=True, force_unicode=False):
     """Attach file contents if file exists.
 
     If key is not specified, the key name will be derived from the file
@@ -68,6 +71,8 @@ def attach_file_if_exists(
 
 
 def read_file(path, force_unicode=False):
+    # TODO: Split into smaller functions/methods
+    # pylint: disable=too-many-return-statements
     """Return the contents of the specified path.
 
     If the contents is valid UTF-8, or force_unicode is True, then the value
@@ -101,7 +106,7 @@ def read_file(path, force_unicode=False):
         except UnicodeDecodeError:
             return contents
     except OSError as error:
-        return "Error: " + str(error)
+        return f"Error: {str(error)}"
 
 
 def attach_file(report, path, key=None, overwrite=True, force_unicode=False):
@@ -139,7 +144,7 @@ def attach_conffiles(report, package, conffiles=None, ui=None):
         if conffiles and path not in conffiles:
             continue
 
-        key = "modified.conffile." + path_to_key(path)
+        key = f"modified.conffile.{path_to_key(path)}"
         if isinstance(contents, str) and (
             contents == "[deleted]" or contents.startswith("[inaccessible")
         ):
@@ -148,9 +153,8 @@ def attach_conffiles(report, package, conffiles=None, ui=None):
 
         if ui:
             response = ui.yesno(
-                'It seems you have modified the contents of "%s".  '
-                "Would you like to add the contents of it to your bug report?"
-                % path
+                f'It seems you have modified the contents of "{path}".  '
+                f"Would you like to add the contents of it to your bug report?"
             )
             if response:
                 report[key] = contents
@@ -160,7 +164,7 @@ def attach_conffiles(report, package, conffiles=None, ui=None):
             report[key] = "[modified]"
 
         mtime = datetime.datetime.fromtimestamp(os.stat(path).st_mtime)
-        report["mtime.conffile." + path_to_key(path)] = mtime.isoformat()
+        report[f"mtime.conffile.{path_to_key(path)}"] = mtime.isoformat()
 
 
 def attach_upstart_overrides(report, package):
@@ -173,7 +177,7 @@ def attach_upstart_overrides(report, package):
     for file in files:
         if os.path.exists(file) and file.startswith("/etc/init/"):
             override = file.replace(".conf", ".override")
-            key = "upstart." + override.replace("/etc/init/", "")
+            key = f"upstart.{override.replace('/etc/init/', '')}"
             attach_file_if_exists(report, override, key)
 
 
@@ -189,16 +193,12 @@ def attach_upstart_logs(report, package):
             continue
         if f.startswith("/usr/share/upstart/sessions/"):
             log = os.path.basename(f).replace(".conf", ".log")
-            key = "upstart." + log
+            key = f"upstart.{log}"
             try:
-                log = os.path.join(
-                    os.environ["XDG_CACHE_HOME"], "upstart", log
-                )
+                log = os.path.join(os.environ["XDG_CACHE_HOME"], "upstart", log)
             except KeyError:
                 try:
-                    log = os.path.join(
-                        os.environ["HOME"], ".cache", "upstart", log
-                    )
+                    log = os.path.join(os.environ["HOME"], ".cache", "upstart", log)
                 except KeyError:
                     continue
 
@@ -206,17 +206,13 @@ def attach_upstart_logs(report, package):
 
         if f.startswith("/usr/share/applications/") and f.endswith(".desktop"):
             desktopname = os.path.splitext(os.path.basename(f))[0]
-            key = "upstart.application." + desktopname
-            log = "application-%s.log" % desktopname
+            key = f"upstart.application.{desktopname}"
+            log = f"application-{desktopname}.log"
             try:
-                log = os.path.join(
-                    os.environ["XDG_CACHE_HOME"], "upstart", log
-                )
+                log = os.path.join(os.environ["XDG_CACHE_HOME"], "upstart", log)
             except KeyError:
                 try:
-                    log = os.path.join(
-                        os.environ["HOME"], ".cache", "upstart", log
-                    )
+                    log = os.path.join(os.environ["HOME"], ".cache", "upstart", log)
                 except KeyError:
                     continue
 
@@ -233,10 +229,11 @@ def attach_dmesg(report):
 
 
 def attach_dmi(report):
+    """Attach Desktop Management Interface (DMI) information to the report."""
     dmi_dir = "/sys/class/dmi/id"
     if os.path.isdir(dmi_dir):
         for f in os.listdir(dmi_dir):
-            p = os.path.realpath("%s/%s" % (dmi_dir, f))
+            p = os.path.realpath(f"{dmi_dir}/{f}")
             st = os.stat(p)
             # ignore the root-only ones, since they have serial numbers
             if not stat.S_ISREG(st.st_mode) or (st.st_mode & 4 == 0):
@@ -249,7 +246,7 @@ def attach_dmi(report):
             except OSError:
                 continue
             if value:
-                report["dmi." + f.replace("_", ".")] = value
+                report[f"dmi.{f.replace('_', '.')}"] = value
 
 
 def attach_hardware(report):
@@ -284,9 +281,7 @@ def attach_hardware(report):
     report["Lsusb-t"] = command_output(["lsusb", "-t"])
     report["ProcModules"] = command_output(["sort", "/proc/modules"])
     report["UdevDb"] = command_output(["udevadm", "info", "--export-db"])
-    report["acpidump"] = root_command_output(
-        ["/usr/share/apport/dump_acpi_tables.py"]
-    )
+    report["acpidump"] = root_command_output(["/usr/share/apport/dump_acpi_tables.py"])
 
     # anonymize partition labels
     labels = report["UdevDb"]
@@ -302,10 +297,9 @@ def attach_hardware(report):
 
     # Use the hardware information to create a machine type.
     if "dmi.sys.vendor" in report and "dmi.product.name" in report:
-        report["MachineType"] = "%s %s" % (
-            report["dmi.sys.vendor"],
-            report["dmi.product.name"],
-        )
+        report[
+            "MachineType"
+        ] = "{report['dmi.sys.vendor']} {report['dmi.product.name']}"
 
     if command_available("prtconf"):
         report["Prtconf"] = command_output(["prtconf"])
@@ -324,13 +318,9 @@ def attach_alsa_old(report):
     for systems where alsa-info is not installed
     (i e, *buntu 12.04 and earlier)
     """
+    attach_file_if_exists(report, os.path.expanduser("~/.asoundrc"), "UserAsoundrc")
     attach_file_if_exists(
-        report, os.path.expanduser("~/.asoundrc"), "UserAsoundrc"
-    )
-    attach_file_if_exists(
-        report,
-        os.path.expanduser("~/.asoundrc.asoundconf"),
-        "UserAsoundrcAsoundconf",
+        report, os.path.expanduser("~/.asoundrc.asoundconf"), "UserAsoundrcAsoundconf"
     )
     attach_file_if_exists(report, "/etc/asound.conf")
     attach_file_if_exists(report, "/proc/asound/version", "AlsaVersion")
@@ -351,24 +341,23 @@ def attach_alsa_old(report):
                     cards.append(int(fields[0]))
 
     for card in cards:
-        key = "Card%d.Amixer.info" % card
+        key = f"Card{card}.Amixer.info"
         report[key] = command_output(["amixer", "-c", str(card), "info"])
-        key = "Card%d.Amixer.values" % card
+        key = f"Card{card}.Amixer.values"
         report[key] = command_output(["amixer", "-c", str(card)])
 
-        for codecpath in glob.glob("/proc/asound/card%d/codec*" % card):
+        for codecpath in glob.glob(f"/proc/asound/card{card}/codec*"):
             if os.path.isfile(codecpath):
                 codec = os.path.basename(codecpath)
-                key = "Card%d.Codecs.%s" % (card, path_to_key(codec))
+                key = f"Card{card}.Codecs.{path_to_key(codec)}"
                 attach_file(report, codecpath, key=key)
             elif os.path.isdir(codecpath):
                 codec = os.path.basename(codecpath)
                 for name in os.listdir(codecpath):
                     path = os.path.join(codecpath, name)
-                    key = "Card%d.Codecs.%s.%s" % (
-                        card,
-                        path_to_key(codec),
-                        path_to_key(name),
+                    key = (
+                        f"Card{card}.Codecs"
+                        f".{path_to_key(codec)}.{path_to_key(name)}"
                     )
                     attach_file(report, path, key)
 
@@ -445,7 +434,7 @@ def command_output(
             env=env,
         )
     except OSError as error:
-        return "Error: " + str(error)
+        return f"Error: {str(error)}"
 
     if sp.returncode == 0:
         res = sp.stdout.strip()
@@ -499,10 +488,10 @@ def _spawn_pkttyagent():
                 if event_type & select.EPOLLHUP:
                     os.close(r)
                     return
-    return
 
 
 def kill_pkttyagent():
+    """Kill pkttyagent (from PolicyKit) if it was started by Apport."""
     global _AGENT  # pylint: disable=global-statement
 
     if _AGENT is None:
@@ -557,13 +546,11 @@ def attach_root_command_outputs(report, command_map):
     Just like root_command_output, this passes the command through pkexec,
     unless the caller is already root.
 
-    This is preferrable to using root_command_output() multiple times, as that
+    This is preferable to using root_command_output() multiple times, as that
     will ask for the password every time.
     """
     wrapper_path = os.path.join(
-        os.path.abspath(
-            os.environ.get("APPORT_DATA_DIR", "/usr/share/apport")
-        ),
+        os.path.abspath(os.environ.get("APPORT_DATA_DIR", "/usr/share/apport")),
         "root_info_wrapper",
     )
     workdir = tempfile.mkdtemp()
@@ -577,10 +564,7 @@ def attach_root_command_outputs(report, command_map):
                 ), "command must be a string (shell command)"
                 # use "| cat" here, so that we can end commands with 2>&1
                 # (otherwise it would have the wrong redirection order)
-                script.write(
-                    "%s | cat > %s\n"
-                    % (command, os.path.join(workdir, keyname))
-                )
+                script.write(f"{command} | cat > {os.path.join(workdir, keyname)}\n")
 
         # run script
         subprocess.run(
@@ -757,9 +741,7 @@ def attach_gsettings_schema(report, schema):
     env = os.environ.copy()
     env["XDG_CONFIG_HOME"] = "/nonexisting"
     with subprocess.Popen(
-        ["gsettings", "list-recursively", schema],
-        env=env,
-        stdout=subprocess.PIPE,
+        ["gsettings", "list-recursively", schema], env=env, stdout=subprocess.PIPE
     ) as gsettings:
         for line in gsettings.stdout:
             try:
@@ -785,7 +767,7 @@ def attach_gsettings_schema(report, schema):
                     b"favorite-apps",
                 ]:
                     value = "redacted by apport"
-                cur_value += "%s %s %s\n" % (schema_name, key, value)
+                cur_value += f"{schema_name} {key} {value}\n"
 
     report["GsettingsChanges"] = cur_value
 
@@ -799,7 +781,7 @@ def attach_gsettings_package(report, package):
         attach_gsettings_schema(report, schema)
 
 
-def attach_journal_errors(report, time_window=10) -> None:
+def attach_journal_errors(report: ProblemReport, time_window: int = 10) -> None:
     """Attach journal warnings and errors.
 
     If the report contains a date, get the journal logs around that
@@ -826,9 +808,7 @@ def attach_network(report):
     report["IpRoute"] = command_output(["ip", "route"])
     report["IpAddr"] = command_output(["ip", "addr"])
     report["PciNetwork"] = pci_devices(PCI_NETWORK)
-    attach_file_if_exists(
-        report, "/etc/network/interfaces", key="IfupdownConfig"
-    )
+    attach_file_if_exists(report, "/etc/network/interfaces", key="IfupdownConfig")
 
     for var in ("http_proxy", "ftp_proxy", "no_proxy"):
         if var in os.environ:
@@ -863,9 +843,7 @@ def attach_wifi(report):
         iw_output = "N/A"
     report["CRDA"] = iw_output
 
-    attach_file_if_exists(
-        report, "/var/log/wpa_supplicant.log", key="WpaSupplicantLog"
-    )
+    attach_file_if_exists(report, "/var/log/wpa_supplicant.log", key="WpaSupplicantLog")
 
 
 def attach_printing(report):
@@ -882,9 +860,7 @@ def attach_printing(report):
     if ppds:
         nicknames = command_output(["fgrep", "-H", "*NickName"] + ppds)
         report["PpdFiles"] = re.sub(
-            r'/etc/cups/ppd/(.*).ppd:\*NickName: *"(.*)"',
-            r"\g<1>: \g<2>",
-            nicknames,
+            r'/etc/cups/ppd/(.*).ppd:\*NickName: *"(.*)"', r"\g<1>: \g<2>", nicknames
         )
 
     report["PrintingPackages"] = package_versions(
@@ -941,13 +917,10 @@ def attach_mac_events(report, profiles=None):
 
     if "AuditLog" not in report and os.path.exists("/var/run/auditd.pid"):
         attach_root_command_outputs(
-            report,
-            {"AuditLog": 'egrep "' + mac_regex + '" /var/log/audit/audit.log'},
+            report, {"AuditLog": f'egrep "{mac_regex}" /var/log/audit/audit.log'}
         )
 
-    attach_file_if_exists(
-        report, "/proc/version_signature", "ProcVersionSignature"
-    )
+    attach_file_if_exists(report, "/proc/version_signature", "ProcVersionSignature")
     attach_file(report, "/proc/cmdline", "ProcCmdline")
 
     for match in re.findall(
@@ -961,14 +934,12 @@ def attach_mac_events(report, profiles=None):
             if match[0] == '"':
                 profile = match[1:-1]
             else:
-                profile = bytes.fromhex(match).decode(
-                    "UTF-8", errors="replace"
-                )
+                profile = bytes.fromhex(match).decode("UTF-8", errors="replace")
         except (IndexError, ValueError):
             continue
 
         for search_profile in profiles:
-            if re.match("^" + search_profile + "$", profile):
+            if re.match(f"^{search_profile}$", profile):
                 report.add_tags(["apparmor"])
                 break
 
@@ -1008,8 +979,7 @@ def package_versions(*packages):
             versions.append((package, version))
 
     package_width = max(len(version[0]) for version in versions)
-    fmt = "%%-%ds %%s" % package_width
-    return "\n".join([fmt % v for v in versions])
+    return "\n".join([f"{p:<{package_width}s} {v}" for (p, v) in versions])
 
 
 def _get_module_license(module):
@@ -1066,7 +1036,7 @@ def __drm_con_info(con):
         if f == "edid":
             val = base64.b64encode(val)
             f += "-base64"
-        info += "%s: %s\n" % (f, val.decode("UTF-8", errors="replace"))
+        info += f"{f}: {val.decode('UTF-8', errors='replace')}\n"
     return info
 
 
@@ -1082,7 +1052,7 @@ def attach_drm_info(report):
         con = os.path.join(drm_dir, f)
         if os.path.exists(os.path.join(con, "enabled")):
             # DRM can set an arbitrary string for its connector paths.
-            report["DRM." + path_to_key(f)] = __drm_con_info(con)
+            report[f"DRM.{path_to_key(f)}"] = __drm_con_info(con)
 
 
 def in_session_of_problem(report):
@@ -1118,9 +1088,7 @@ def in_session_of_problem(report):
 
     # determine session creation time
     try:
-        session_start_time = os.stat(
-            "/run/systemd/sessions/" + session_id
-        ).st_mtime
+        session_start_time = os.stat(f"/run/systemd/sessions/{session_id}").st_mtime
     except OSError:
         return None
 
