@@ -12,6 +12,7 @@ import typing
 import unittest.mock
 import urllib.error
 import urllib.request
+from typing import Any, Optional
 
 
 def get_init_system() -> str:
@@ -38,7 +39,7 @@ def has_internet() -> bool:
         return False
 
 
-def import_module_from_file(path: pathlib.Path):
+def import_module_from_file(path: pathlib.Path) -> Any:
     """Import a module by its filename."""
     name = path.stem.replace("-", "_")
     spec = importlib.util.spec_from_loader(
@@ -65,7 +66,7 @@ def pidof(program):
     return set(int(pid) for pid in stdout.decode().split())
 
 
-def read_shebang(command: str) -> typing.Optional[str]:
+def read_shebang(command: str) -> Optional[str]:
     """Return the shebang of the given file.
 
     If the given file is a script, return the executable from the
@@ -82,7 +83,7 @@ def _id(obj):
     return obj
 
 
-def skip_if_command_is_missing(cmd: str):
+def skip_if_command_is_missing(cmd: str) -> typing.Callable:
     """Skip a test if the command is not found."""
     if shutil.which(cmd) is None:
         return unittest.skip(f"{cmd} not installed")
