@@ -13,14 +13,15 @@ import os
 import shutil
 import subprocess
 import tempfile
-import typing
 import unittest
+from typing import Optional
 
 import apport.report
 from tests.paths import get_data_directory, local_test_environment
 
 
 class TestApportCheckreports(unittest.TestCase):
+    # pylint: disable=missing-function-docstring
     """Test apport-checkreports"""
 
     def setUp(self):
@@ -35,7 +36,7 @@ class TestApportCheckreports(unittest.TestCase):
 
     def _call(
         self,
-        args: typing.Optional[list] = None,
+        args: Optional[list] = None,
         expected_returncode: int = 0,
         expected_stdout: str = "",
     ) -> None:
