@@ -19,27 +19,28 @@ import problem_report
 from tests.paths import local_test_environment
 
 
-class T(unittest.TestCase):
+class TestApportUnpack(unittest.TestCase):
+    # pylint: disable=missing-class-docstring,missing-function-docstring
+    env: dict[str, str]
+
     @classmethod
     def setUpClass(cls):
-        cls.env = (
-            os.environ | local_test_environment() | {"LANGUAGE": "C.UTF-8"}
-        )
+        cls.env = os.environ | local_test_environment() | {"LANGUAGE": "C.UTF-8"}
         cls.workdir = tempfile.mkdtemp()
 
         # create problem report file with all possible data types
-        r = problem_report.ProblemReport()
+        report = problem_report.ProblemReport()
         cls.utf8_str = b"a\xe2\x99\xa5b"
         cls.bindata = b"\x00\x01\xFF\x40"
-        r["utf8"] = cls.utf8_str
-        r["unicode"] = cls.utf8_str.decode("UTF-8")
-        r["binary"] = cls.bindata
-        r["compressed"] = problem_report.CompressedValue(b"FooFoo!")
-        r["separator"] = ""
+        report["utf8"] = cls.utf8_str
+        report["unicode"] = cls.utf8_str.decode("UTF-8")
+        report["binary"] = cls.bindata
+        report["compressed"] = problem_report.CompressedValue(b"FooFoo!")
+        report["separator"] = ""
 
         cls.report_file = os.path.join(cls.workdir, "test.apport")
-        with open(cls.report_file, "wb") as f:
-            r.write(f)
+        with open(cls.report_file, "wb") as report_file:
+            report.write(report_file)
 
         cls.unpack_dir = os.path.join(cls.workdir, "un pack")
 
@@ -82,9 +83,7 @@ class T(unittest.TestCase):
         self.assertEqual(process.stdout, "")
         self.assertTrue(process.stderr.startswith("usage:"), process.stderr)
 
-        process = self._call_apport_unpack(
-            ["/nonexisting.crash", self.unpack_dir]
-        )
+        process = self._call_apport_unpack(["/nonexisting.crash", self.unpack_dir])
         self.assertEqual(process.returncode, 1)
         self.assertIn("/nonexisting.crash", process.stderr)
         self.assertEqual(process.stdout, "")
@@ -93,9 +92,7 @@ class T(unittest.TestCase):
         with tempfile.NamedTemporaryFile("wb") as report_file:
             report_file.write(b"AB\xfc:CD\n")
             report_file.flush()
-            process = self._call_apport_unpack(
-                [report_file.name, self.unpack_dir]
-            )
+            process = self._call_apport_unpack([report_file.name, self.unpack_dir])
 
         self.assertEqual(process.returncode, 1)
         self.assertEqual(
@@ -106,6 +103,24 @@ class T(unittest.TestCase):
         )
         self.assertEqual(process.stdout, "")
 
+    def test_broken_core_dump(self):
+        """Test unpacking a report file that has a malformed CoreDump entry."""
+        with tempfile.NamedTemporaryFile("wb") as report_file:
+            report_file.write(
+                b"CoreDump: base64\n H4sICAAAAAAC/0NvcmVEdW1wAA==\n"
+                b" 7Z0LYFPV/cdP0rQ\n"
+            )
+            report_file.flush()
+            process = self._call_apport_unpack([report_file.name, self.unpack_dir])
+
+        self.assertEqual(process.returncode, 1)
+        self.assertEqual(
+            process.stderr,
+            "ERROR: Malformed problem report: Incorrect padding. "
+            "Is this a proper .crash text file?\n",
+        )
+        self.assertEqual(process.stdout, "")
+
     def _call_apport_unpack(self, argv: list) -> subprocess.CompletedProcess:
         return subprocess.run(
             ["apport-unpack"] + argv,
@@ -117,5 +132,5 @@ class T(unittest.TestCase):
         )
 
     def _get_unpack(self, fname):
-        with open(os.path.join(self.unpack_dir, fname), "rb") as f:
-            return f.read()
+        with open(os.path.join(self.unpack_dir, fname), "rb") as file_:
+            return file_.read()
