@@ -1,3 +1,8 @@
+"""Integration tests for the apport.hookutils module."""
+
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import locale
 import os
 import re
@@ -15,6 +20,8 @@ from tests.helper import skip_if_command_is_missing
 
 
 class T(unittest.TestCase):
+    """Integration tests for the apport.hookutils module."""
+
     def setUp(self):
         self.workdir = tempfile.mkdtemp()
 
@@ -29,15 +36,11 @@ class T(unittest.TestCase):
         def _build_ko(license_name):
             ko_filename = os.path.join(self.workdir, f"{license_name}.ko")
             with tempfile.NamedTemporaryFile(
-                mode="w+", prefix="%s-" % (license_name), suffix=".S"
+                mode="w+", prefix=f"{license_name}-", suffix=".S"
             ) as asm:
-                asm.write(
-                    f'.section .modinfo\n.string "license={license_name}"\n'
-                )
+                asm.write(f'.section .modinfo\n.string "license={license_name}"\n')
                 asm.flush()
-                subprocess.check_call(
-                    ["/usr/bin/as", asm.name, "-o", ko_filename]
-                )
+                subprocess.check_call(["/usr/bin/as", asm.name, "-o", ko_filename])
             return ko_filename
 
         good_ko = _build_ko("GPL")
@@ -117,9 +120,7 @@ class T(unittest.TestCase):
         link = os.path.join(self.workdir, "dirsymlink")
         os.symlink("/etc", link)
         report = {}
-        apport.hookutils.attach_file(
-            report, os.path.join(link, "passwd"), "DirSymlink"
-        )
+        apport.hookutils.attach_file(report, os.path.join(link, "passwd"), "DirSymlink")
         self.assertEqual(list(report), ["DirSymlink"])
         self.assertTrue(report["DirSymlink"].startswith("Error: "))
 
@@ -139,9 +140,7 @@ class T(unittest.TestCase):
         apport.hookutils.attach_file(
             report, "/etc/issue", ".etc.passwd", overwrite=False
         )
-        self.assertEqual(
-            sorted(report.keys()), [".etc.passwd", ".etc.passwd_"]
-        )
+        self.assertEqual(sorted(report.keys()), [".etc.passwd", ".etc.passwd_"])
         self.assertEqual(report[".etc.passwd"], passwd_contents)
         self.assertEqual(report[".etc.passwd_"], issue_contents)
 
@@ -155,12 +154,8 @@ class T(unittest.TestCase):
         apport.hookutils.attach_file(report, myfile, key="data")
         self.assertEqual(report["data"], b"a\xc3\xb6b\xffx")
 
-        apport.hookutils.attach_file(
-            report, myfile, key="data", force_unicode=True
-        )
-        self.assertEqual(
-            report["data"], b"a\xc3\xb6b\xef\xbf\xbdx".decode("UTF-8")
-        )
+        apport.hookutils.attach_file(report, myfile, key="data", force_unicode=True)
+        self.assertEqual(report["data"], b"a\xc3\xb6b\xef\xbf\xbdx".decode("UTF-8"))
 
     def test_attach_file_if_exists(self):
         """attach_file_if_exists()"""
@@ -200,29 +195,24 @@ class T(unittest.TestCase):
     def test_recent_syslog(self):
         """recent_syslog"""
         self.assertEqual(
-            apport.hookutils.recent_syslog(
-                re.compile("."), path="/nonexisting"
-            ),
-            "",
+            apport.hookutils.recent_syslog(re.compile("."), path="/nonexisting"), ""
         )
         self.assertEqual(
-            apport.hookutils.recent_syslog(
-                re.compile("ThisCantPossiblyHitAnything")
-            ),
+            apport.hookutils.recent_syslog(re.compile("ThisCantPossiblyHitAnything")),
             "",
         )
         if os.path.exists("/run/systemd/system") or os.access(
             "/var/log/syslog", os.R_OK
         ):
-            self.assertNotEqual(
-                len(apport.hookutils.recent_syslog(re.compile("."))), 0
-            )
+            self.assertNotEqual(len(apport.hookutils.recent_syslog(re.compile("."))), 0)
 
     @unittest.mock.patch(
         "apport.hookutils._root_command_prefix",
         unittest.mock.MagicMock(return_value=[]),
     )
     def test_attach_mac_events(self):
+        # TODO: Split into separate test cases
+        # pylint: disable=too-many-statements
         """attach_mac_events()"""
         denied_log = (
             "[  351.624338] type=1400 audit(1343775571.688:27):"
@@ -376,7 +366,7 @@ class T(unittest.TestCase):
         data = apport.hookutils.recent_syslog(re.compile("kernel"), path=log)
         mem_after = self._get_mem_usage()
         delta_kb = mem_after - mem_before
-        sys.stderr.write("[Δ %i kB] " % delta_kb)
+        sys.stderr.write(f"[Δ {delta_kb} kB] ")
         self.assertLess(delta_kb, 5000)
 
         self.assertTrue(
@@ -386,9 +376,7 @@ class T(unittest.TestCase):
         self.assertLess(len(data), 1000000)
 
     @unittest.skipIf(
-        apport.hookutils.apport.hookutils.in_session_of_problem(
-            apport.report.Report()
-        )
+        apport.hookutils.apport.hookutils.in_session_of_problem(apport.report.Report())
         is None,
         "no logind session",
     )
@@ -423,9 +411,7 @@ class T(unittest.TestCase):
     def test_xsession_errors(self):
         """xsession_errors()"""
         with open(
-            os.path.join(self.workdir, ".xsession-errors"),
-            "w",
-            encoding="UTF-8",
+            os.path.join(self.workdir, ".xsession-errors"), "w", encoding="UTF-8"
         ) as f:
             f.write(
                 """\
@@ -508,6 +494,7 @@ GdkPixbuf-CRITICAL **: gdk_pixbuf_scale_simple: another standard glib assertion
         apport.hookutils.attach_default_grub(report)
 
     def test_command_output(self):
+        """Test apport.hookutils.command_output."""
         orig_lcm = os.environ.get("LC_MESSAGES")
         os.environ["LC_MESSAGES"] = "en_US.UTF-8"
         try:
