@@ -1,9 +1,16 @@
+"""Integration tests for the apport.packaging module."""
+
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import unittest
 
 import apport.packaging
 
 
 class T(unittest.TestCase):
+    """Integration tests for the apport.packaging module."""
+
     def test_get_uninstalled_package(self):
         """get_uninstalled_package()"""
         p = apport.packaging.get_uninstalled_package()
