@@ -1,3 +1,8 @@
+"""Integration tests for the apport.packaging_impl.apt_dpkg module."""
+
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import gzip
 import os
 import pathlib
@@ -13,6 +18,7 @@ from tests.helper import skip_if_command_is_missing
 
 @skip_if_command_is_missing("dpkg")
 class T(unittest.TestCase):
+    # pylint: disable=missing-class-docstring,missing-function-docstring
     # pylint: disable=protected-access
 
     def setUp(self):
@@ -45,41 +51,27 @@ class T(unittest.TestCase):
             # use one relative and one absolute path in checksums file
             with open(sumfile, "wb") as fd:
                 fd.write(
-                    b"2e41290da2fa3f68bd3313174467e3b5  "
-                    + f1[1:].encode()
-                    + b"\n"
-                )
-                fd.write(
-                    b"f6423dfbc4faf022e58b4d3f5ff71a70  " + f2.encode() + b"\n"
+                    b"2e41290da2fa3f68bd3313174467e3b5  " + f1[1:].encode() + b"\n"
                 )
+                fd.write(b"f6423dfbc4faf022e58b4d3f5ff71a70  " + f2.encode() + b"\n")
                 fd.write(b"deadbeef000001111110000011110000  /bin/\xc3\xa4")
-            self.assertEqual(
-                impl._check_files_md5(sumfile), [], "correct md5sums"
-            )
+            self.assertEqual(impl._check_files_md5(sumfile), [], "correct md5sums")
 
             with open(f1, "w", encoding="utf-8") as fd:
                 fd.write("Some stuff!")
-            self.assertEqual(
-                impl._check_files_md5(sumfile), [f1[1:]], "file 1 wrong"
-            )
+            self.assertEqual(impl._check_files_md5(sumfile), [f1[1:]], "file 1 wrong")
             with open(f2, "w", encoding="utf-8") as fd:
                 fd.write("More stuff!")
             self.assertEqual(
-                impl._check_files_md5(sumfile),
-                [f1[1:], f2],
-                "files 1 and 2 wrong",
+                impl._check_files_md5(sumfile), [f1[1:], f2], "files 1 and 2 wrong"
             )
             with open(f1, "w", encoding="utf-8") as fd:
                 fd.write("Some stuff")
-            self.assertEqual(
-                impl._check_files_md5(sumfile), [f2], "file 2 wrong"
-            )
+            self.assertEqual(impl._check_files_md5(sumfile), [f2], "file 2 wrong")
 
             # check using a direct md5 list as argument
             with open(sumfile, "rb") as fd:
-                self.assertEqual(
-                    impl._check_files_md5(fd.read()), [f2], "file 2 wrong"
-                )
+                self.assertEqual(impl._check_files_md5(fd.read()), [f2], "file 2 wrong")
 
         finally:
             shutil.rmtree(td)
@@ -93,9 +85,7 @@ class T(unittest.TestCase):
     def test_get_available_version(self):
         """get_available_version()."""
         self.assertTrue(impl.get_available_version("libc6").startswith("2"))
-        self.assertRaises(
-            ValueError, impl.get_available_version, "nonexisting"
-        )
+        self.assertRaises(ValueError, impl.get_available_version, "nonexisting")
 
     def test_get_dependencies(self):
         """get_dependencies()."""
@@ -167,9 +157,7 @@ class T(unittest.TestCase):
         """get_file_package() on installed files."""
         self.assertEqual(impl.get_file_package("/bin/bash"), "bash")
         self.assertEqual(impl.get_file_package("/bin/cat"), "coreutils")
-        self.assertEqual(
-            impl.get_file_package("/etc/pam.conf"), "libpam-runtime"
-        )
+        self.assertEqual(impl.get_file_package("/etc/pam.conf"), "libpam-runtime")
         self.assertEqual(impl.get_file_package("/nonexisting"), None)
 
     def test_get_file_package_uninstalled(self):
@@ -181,9 +169,7 @@ class T(unittest.TestCase):
             mapdir = os.path.join(basedir, "dists", impl.get_distro_codename())
             os.makedirs(mapdir)
             with gzip.open(
-                os.path.join(
-                    mapdir, "Contents-%s.gz" % impl.get_system_architecture()
-                ),
+                os.path.join(mapdir, f"Contents-{impl.get_system_architecture()}.gz"),
                 "w",
             ) as f:
                 f.write(
@@ -197,13 +183,11 @@ bin/true                                                admin/superutils
 
             # test Contents.gz for -updates pocket
             mapdir = os.path.join(
-                basedir, "dists", impl.get_distro_codename() + "-updates"
+                basedir, "dists", f"{impl.get_distro_codename()}-updates"
             )
             os.makedirs(mapdir)
             with gzip.open(
-                os.path.join(
-                    mapdir, "Contents-%s.gz" % impl.get_system_architecture()
-                ),
+                os.path.join(mapdir, f"Contents-{impl.get_system_architecture()}.gz"),
                 "w",
             ) as f:
                 f.write(
@@ -212,58 +196,39 @@ bin/true                                                admin/superutils
                 )
 
             # use this as a mirror
-            impl.set_mirror("file://" + basedir)
+            impl.set_mirror(f"file://{basedir}")
 
-            self.assertEqual(
-                impl.get_file_package("usr/bin/frob", False), None
-            )
+            self.assertEqual(impl.get_file_package("usr/bin/frob", False), None)
             # must not match frob (same file name prefix)
-            self.assertEqual(
-                impl.get_file_package("usr/bin/frob", True), "frob-utils"
-            )
-            self.assertEqual(
-                impl.get_file_package("/usr/bin/frob", True), "frob-utils"
-            )
+            self.assertEqual(impl.get_file_package("usr/bin/frob", True), "frob-utils")
+            self.assertEqual(impl.get_file_package("/usr/bin/frob", True), "frob-utils")
             # find files from -updates pocket
-            self.assertEqual(
-                impl.get_file_package("/lib/libnew.so.5", False), None
-            )
-            self.assertEqual(
-                impl.get_file_package("/lib/libnew.so.5", True), "libnew5"
-            )
+            self.assertEqual(impl.get_file_package("/lib/libnew.so.5", False), None)
+            self.assertEqual(impl.get_file_package("/lib/libnew.so.5", True), "libnew5")
 
             # invalid mirror
             impl.set_mirror("file:///foo/nonexisting")
-            self.assertRaises(
-                OSError, impl.get_file_package, "usr/bin/frob", True
-            )
+            self.assertRaises(OSError, impl.get_file_package, "usr/bin/frob", True)
 
             # valid mirror, test cache directory
-            impl.set_mirror("file://" + basedir)
+            impl.set_mirror(f"file://{basedir}")
             cache_dir = os.path.join(basedir, "cache")
             os.mkdir(cache_dir)
             self.assertEqual(
-                impl.get_file_package("usr/bin/frob", True, cache_dir),
-                "frob-utils",
+                impl.get_file_package("usr/bin/frob", True, cache_dir), "frob-utils"
             )
             cache_dir_files = sorted(os.listdir(cache_dir))
             self.assertEqual(len(cache_dir_files), 3)
-            self.assertEqual(
-                impl.get_file_package("/bo/gu/s", True, cache_dir), None
-            )
+            self.assertEqual(impl.get_file_package("/bo/gu/s", True, cache_dir), None)
 
             # valid cache, should not need to access the mirror
             impl.set_mirror("file:///foo/nonexisting")
             self.assertEqual(
-                impl.get_file_package("/bin/true", True, cache_dir),
-                "superutils",
+                impl.get_file_package("/bin/true", True, cache_dir), "superutils"
             )
+            self.assertEqual(impl.get_file_package("/bo/gu/s", True, cache_dir), None)
             self.assertEqual(
-                impl.get_file_package("/bo/gu/s", True, cache_dir), None
-            )
-            self.assertEqual(
-                impl.get_file_package("/lib/libnew.so.5", True, cache_dir),
-                "libnew5",
+                impl.get_file_package("/lib/libnew.so.5", True, cache_dir), "libnew5"
             )
 
             # outdated cache, must refresh the cache and hit the invalid
@@ -307,8 +272,7 @@ usr/bin/frob                                            foo/frob-utils
             # and another one for fantasy release
             os.mkdir(os.path.join(basedir, "dists", "mocky"))
             with gzip.open(
-                os.path.join(basedir, "dists", "mocky", "Contents-even.gz"),
-                "w",
+                os.path.join(basedir, "dists", "mocky", "Contents-even.gz"), "w"
             ) as f:
                 f.write(
                     b"""\
@@ -318,37 +282,27 @@ usr/bin/frob                                            foo/frob
                 )
 
             # use this as a mirror
-            impl.set_mirror("file://" + basedir)
+            impl.set_mirror(f"file://{basedir}")
 
             # must not match system architecture
-            self.assertEqual(
-                impl.get_file_package("usr/bin/frob", False), None
-            )
+            self.assertEqual(impl.get_file_package("usr/bin/frob", False), None)
             # must match correct architecture
             self.assertEqual(
-                impl.get_file_package("usr/bin/frob", True, arch="even"),
-                "frob-utils",
+                impl.get_file_package("usr/bin/frob", True, arch="even"), "frob-utils"
             )
             self.assertEqual(
-                impl.get_file_package("usr/bin/frob", True, arch="odd"),
-                "frob-utils",
+                impl.get_file_package("usr/bin/frob", True, arch="odd"), "frob-utils"
             )
             self.assertEqual(
-                impl.get_file_package(
-                    "/usr/lib/even/libfrob.so.1", True, arch="even"
-                ),
+                impl.get_file_package("/usr/lib/even/libfrob.so.1", True, arch="even"),
                 "libfrob1",
             )
             self.assertEqual(
-                impl.get_file_package(
-                    "/usr/lib/even/libfrob.so.1", True, arch="odd"
-                ),
+                impl.get_file_package("/usr/lib/even/libfrob.so.1", True, arch="odd"),
                 None,
             )
             self.assertEqual(
-                impl.get_file_package(
-                    "/usr/lib/odd/libfrob.so.1", True, arch="odd"
-                ),
+                impl.get_file_package("/usr/lib/odd/libfrob.so.1", True, arch="odd"),
                 "libfrob1",
             )
 
@@ -397,7 +351,7 @@ usr/bin/frob                                            foo/frob
             )
 
             # valid mirror, test caching
-            impl.set_mirror("file://" + basedir)
+            impl.set_mirror(f"file://{basedir}")
             cache_dir = os.path.join(basedir, "cache")
             os.mkdir(cache_dir)
             self.assertEqual(
@@ -423,18 +377,12 @@ usr/bin/frob                                            foo/frob
             # valid cache, should not need to access the mirror
             impl.set_mirror("file:///foo/nonexisting")
             self.assertEqual(
-                impl.get_file_package(
-                    "usr/bin/frob", True, cache_dir, arch="even"
-                ),
+                impl.get_file_package("usr/bin/frob", True, cache_dir, arch="even"),
                 "frob-utils",
             )
             self.assertEqual(
                 impl.get_file_package(
-                    "usr/bin/frob",
-                    True,
-                    cache_dir,
-                    release="Foonux 3.14",
-                    arch="even",
+                    "usr/bin/frob", True, cache_dir, release="Foonux 3.14", arch="even"
                 ),
                 "frob",
             )
@@ -453,9 +401,7 @@ usr/bin/frob                                            foo/frob
             # mirror
             now = int(time.time())
             for cache_file in os.listdir(cache_dir):
-                os.utime(
-                    os.path.join(cache_dir, cache_file), (now, now - 90000)
-                )
+                os.utime(os.path.join(cache_dir, cache_file), (now, now - 90000))
 
             self.assertRaises(
                 OSError,
@@ -471,9 +417,7 @@ usr/bin/frob                                            foo/frob
 
     def test_get_file_package_diversion(self):
         """get_file_package() for a diverted file."""
-        output = subprocess.check_output(
-            ["dpkg-divert", "--list"], env={}
-        ).decode()
+        output = subprocess.check_output(["dpkg-divert", "--list"], env={}).decode()
 
         for line in output.rstrip().split("\n"):
             fields = line.split(" ")
@@ -482,9 +426,7 @@ usr/bin/frob                                            foo/frob
                 # pick first diversion we have
                 break
         else:  # pragma: no cover
-            self.fail(
-                f"No non-local diversion found. dpkg-divert output: {output}"
-            )
+            self.fail(f"No non-local diversion found. dpkg-divert output: {output}")
 
         file = fields[2]
         pkg = fields[-1]
@@ -505,7 +447,7 @@ deb http://secondary.mirror tuxy extra
             )
             f.flush()
             self.assertEqual(
-                impl._get_primary_mirror_from_apt_sources(s),
+                impl._get_primary_mirror_from_apt_sources(self.workdir),
                 "http://binary.mirror/tuxy",
             )
 
@@ -520,7 +462,7 @@ deb http://secondary.mirror tuxy extra
             )
             f.flush()
             self.assertEqual(
-                impl._get_primary_mirror_from_apt_sources(s),
+                impl._get_primary_mirror_from_apt_sources(self.workdir),
                 "http://binary.mirror/tuxy",
             )
 
@@ -528,7 +470,7 @@ deb http://secondary.mirror tuxy extra
         with open(s, "w", encoding="utf-8") as f:
             f.flush()
         self.assertRaises(
-            SystemError, impl._get_primary_mirror_from_apt_sources, s
+            SystemError, impl._get_primary_mirror_from_apt_sources, self.workdir
         )
 
     def test_mirror_from_apt_sources_with_options(self) -> None:
@@ -536,7 +478,7 @@ deb http://secondary.mirror tuxy extra
         sources = pathlib.Path(self.workdir) / "sources.list"
         expected = "https://example.com/"
         sources.write_text(f"deb [ arch=riscv64 ] {expected} suite component")
-        actual = impl._get_primary_mirror_from_apt_sources(str(sources))
+        actual = impl._get_primary_mirror_from_apt_sources(self.workdir)
         self.assertEqual(actual, expected)
 
     def test_get_modified_conffiles(self):
@@ -544,9 +486,7 @@ deb http://secondary.mirror tuxy extra
         # very shallow
         self.assertEqual(type(impl.get_modified_conffiles("bash")), type({}))
         self.assertEqual(type(impl.get_modified_conffiles("apport")), type({}))
-        self.assertEqual(
-            type(impl.get_modified_conffiles("nonexisting")), type({})
-        )
+        self.assertEqual(type(impl.get_modified_conffiles("nonexisting")), type({}))
 
     def test_get_system_architecture(self):
         """get_system_architecture()."""
@@ -568,15 +508,9 @@ deb http://secondary.mirror tuxy extra
     def test_compare_versions(self):
         """compare_versions."""
         self.assertEqual(impl.compare_versions("1", "2"), -1)
-        self.assertEqual(
-            impl.compare_versions("1.0-1ubuntu1", "1.0-1ubuntu2"), -1
-        )
-        self.assertEqual(
-            impl.compare_versions("1.0-1ubuntu1", "1.0-1ubuntu1"), 0
-        )
-        self.assertEqual(
-            impl.compare_versions("1.0-1ubuntu2", "1.0-1ubuntu1"), 1
-        )
+        self.assertEqual(impl.compare_versions("1.0-1ubuntu1", "1.0-1ubuntu2"), -1)
+        self.assertEqual(impl.compare_versions("1.0-1ubuntu1", "1.0-1ubuntu1"), 0)
+        self.assertEqual(impl.compare_versions("1.0-1ubuntu2", "1.0-1ubuntu1"), 1)
         self.assertEqual(impl.compare_versions("1:1.0-1", "2007-2"), 1)
         self.assertEqual(impl.compare_versions("1:1.0-1~1", "1:1.0-1"), -1)
 
