@@ -1,3 +1,5 @@
+"""Integration tests for the apport.packaging_impl.rpm module."""
+
 import unittest
 
 from tests.helper import skip_if_command_is_missing
@@ -12,7 +14,9 @@ except ImportError:
 
 @unittest.skipUnless(HAS_RPM, "rpm module not available")
 @skip_if_command_is_missing("rpm")
-class T(unittest.TestCase):
+class TestPackagingRpm(unittest.TestCase):
+    """Integration tests for the apport.packaging_impl.rpm module."""
+
     def test_get_dependencies(self):
         """get_dependencies()."""
         deps = impl.get_dependencies("bash")
@@ -27,9 +31,9 @@ class T(unittest.TestCase):
     def test_get_headers_by_tag(self):
         """_get_headers_by_tag()."""
         # pylint: disable=protected-access
-        headersByTag = impl._get_headers_by_tag("basenames", "/bin/bash")
-        self.assertEqual(len(headersByTag), 1)
-        self.assertTrue(headersByTag[0]["n"].startswith("bash"))
+        headers_by_tag = impl._get_headers_by_tag("basenames", "/bin/bash")
+        self.assertEqual(len(headers_by_tag), 1)
+        self.assertTrue(headers_by_tag[0]["n"].startswith("bash"))
 
     def test_get_system_architecture(self):
         """get_system_architecture()."""
