@@ -1,3 +1,8 @@
+"""Integration tests for the problem_report module."""
+
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import email
 import gzip
 import io
@@ -14,6 +19,8 @@ bin_data = b"ABABABABAB\0\0\0Z\x01\x02"
 
 
 class T(unittest.TestCase):
+    # pylint: disable=missing-class-docstring,missing-function-docstring
+
     def setUp(self):
         self.workdir = tempfile.mkdtemp()
 
@@ -46,12 +53,8 @@ class T(unittest.TestCase):
         pr["Large"].write(out)
         self.assertEqual(out.getvalue(), large_val)
 
-        pr["Multiline"] = problem_report.CompressedValue(
-            b"\1\1\1\n\2\2\n\3\3\3"
-        )
-        self.assertEqual(
-            pr["Multiline"].splitlines(), [b"\1\1\1", b"\2\2", b"\3\3\3"]
-        )
+        pr["Multiline"] = problem_report.CompressedValue(b"\1\1\1\n\2\2\n\3\3\3")
+        self.assertEqual(pr["Multiline"].splitlines(), [b"\1\1\1", b"\2\2", b"\3\3\3"])
 
         # test writing of reports with CompressedValues
         out = io.BytesIO()
@@ -125,9 +128,7 @@ class T(unittest.TestCase):
         pr["Bin"] = problem_report.CompressedValue()
         pr["Bin"].set_value(bin_data)
         pr["Large"] = problem_report.CompressedValue(large_val)
-        pr["Multiline"] = problem_report.CompressedValue(
-            b"\1\1\1\n\2\2\n\3\3\3"
-        )
+        pr["Multiline"] = problem_report.CompressedValue(b"\1\1\1\n\2\2\n\3\3\3")
 
         report = io.BytesIO()
         pr.write(report)
@@ -138,7 +139,7 @@ class T(unittest.TestCase):
             pr.extract_keys,
             report,
             "Bin",
-            os.path.join(self.workdir, "nonexistant"),
+            os.path.join(self.workdir, "nonexistent"),
         )
         # Test exception handling: Non-binary and nonexistent key
         tests = [
@@ -149,9 +150,7 @@ class T(unittest.TestCase):
         ]
         for exc, keys_arg in tests:
             report.seek(0)
-            self.assertRaises(
-                exc, pr.extract_keys, report, keys_arg, self.workdir
-            )
+            self.assertRaises(exc, pr.extract_keys, report, keys_arg, self.workdir)
 
         # Check valid single elements
         tests = {
@@ -341,7 +340,7 @@ class T(unittest.TestCase):
         self.assertEqual(pr["Before"], "xtestx")
         self.assertEqual(pr["ZAfter"], "ytesty")
 
-    def test_add_to_existing(self):
+    def test_add_to_existing(self):  # pylint: disable=too-many-statements
         """Add information to an existing report."""
         # original report
         pr = problem_report.ProblemReport()
@@ -402,9 +401,7 @@ class T(unittest.TestCase):
                 with open("/proc/mounts", encoding="utf-8") as f:
                     for line in f:
                         mount, _, options = line.split(" ")[1:4]
-                        if mount == directory and "noatime" in options.split(
-                            ","
-                        ):
+                        if mount == directory and "noatime" in options.split(","):
                             skip_atime = True
                             break
                 break
