@@ -1,3 +1,9 @@
+"""Integration tests for the apport.report module."""
+
+# pylint: disable=too-many-lines
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import atexit
 import grp
 import io
@@ -19,7 +25,9 @@ from tests.paths import patch_data_dir, restore_data_dir
 
 
 class T(unittest.TestCase):
-    # pylint: disable=protected-access
+    # pylint: disable=missing-function-docstring
+    # pylint: disable=protected-access,too-many-public-methods
+    """Test apport.report module."""
 
     @classmethod
     def setUpClass(cls):
@@ -29,7 +37,7 @@ class T(unittest.TestCase):
     def tearDownClass(cls):
         restore_data_dir(apport.report, cls.orig_data_dir)
 
-    def wait_for_proc_cmdline(self, pid: int, timeout_sec=10.0) -> None:
+    def wait_for_proc_cmdline(self, pid: int, timeout_sec: float = 10.0) -> None:
         assert pid
         elapsed_time = 0.0
         while elapsed_time < timeout_sec:
@@ -41,8 +49,7 @@ class T(unittest.TestCase):
             elapsed_time += 0.1
 
         self.fail(
-            f"/proc/{pid}/cmdline not readable within"
-            f" {int(elapsed_time)} seconds."
+            f"/proc/{pid}/cmdline not readable within" f" {int(elapsed_time)} seconds."
         )
 
     @unittest.mock.patch("time.sleep")
@@ -115,6 +122,8 @@ class T(unittest.TestCase):
         self.assertNotIn(grp.getgrgid(os.getgid()).gr_name, pr["UserGroups"])
 
     def test_add_proc_info(self):
+        # TODO: Split into separate test cases
+        # pylint: disable=too-many-statements
         """add_proc_info()."""
         # check without additional safe environment variables
         pr = apport.report.Report()
@@ -122,9 +131,9 @@ class T(unittest.TestCase):
         pr.add_proc_info()
         self.assertEqual(pr.pid, os.getpid())
         self.assertTrue(
-            set(
-                ["ProcEnviron", "ProcMaps", "ProcCmdline", "ProcMaps"]
-            ).issubset(set(pr.keys())),
+            set(["ProcEnviron", "ProcMaps", "ProcCmdline", "ProcMaps"]).issubset(
+                set(pr.keys())
+            ),
             "report has required fields",
         )
         if "LANG" in os.environ:
@@ -135,8 +144,7 @@ class T(unittest.TestCase):
         self.assertNotIn("PWD", pr["ProcEnviron"])
         self.assertRegex(pr["ExecutablePath"], r".*\.py$")
         self.assertEqual(
-            int(pr["ExecutableTimestamp"]),
-            int(os.stat(pr["ExecutablePath"]).st_mtime),
+            int(pr["ExecutableTimestamp"]), int(os.stat(pr["ExecutablePath"]).st_mtime)
         )
 
         # check with one additional safe environment variable
@@ -153,17 +161,13 @@ class T(unittest.TestCase):
             os.setresuid(8, 8, -1)
             restore_root = True
         pr = apport.report.Report()
-        self.assertRaises(
-            ValueError, pr.add_proc_info, 1
-        )  # EPERM for init process
+        self.assertRaises(ValueError, pr.add_proc_info, 1)  # EPERM for init process
         if restore_root:
             os.setresuid(0, 0, -1)
 
         self.assertEqual(pr.pid, 1)
         self.assertIn("Pid:\t1", pr["ProcStatus"])
-        self.assertTrue(
-            pr["ProcEnviron"].startswith("Error:"), pr["ProcEnviron"]
-        )
+        self.assertTrue(pr["ProcEnviron"].startswith("Error:"), pr["ProcEnviron"])
         self.assertNotIn("InterpreterPath", pr)
 
         # check escaping of ProcCmdline
@@ -178,18 +182,14 @@ class T(unittest.TestCase):
             pr.add_proc_info(pid=cat.pid)
             self.assertEqual(pr.pid, cat.pid)
             cat.communicate(b"\n")
-        self.assertEqual(
-            pr["ProcCmdline"], "cat /foo\\ bar \\\\h \\\\\\ \\\\ -"
-        )
+        self.assertEqual(pr["ProcCmdline"], "cat /foo\\ bar \\\\h \\\\\\ \\\\ -")
         self.assertEqual(pr["ExecutablePath"], "/usr/bin/cat")
         self.assertNotIn("InterpreterPath", pr)
         self.assertIn("/bin/cat", pr["ProcMaps"])
         self.assertIn("[stack]", pr["ProcMaps"])
 
         # check correct handling of executable symlinks
-        assert os.path.islink(
-            "/bin/sh"
-        ), "/bin/sh needs to be a symlink for this test"
+        assert os.path.islink("/bin/sh"), "/bin/sh needs to be a symlink for this test"
         with subprocess.Popen(["sh"], stdin=subprocess.PIPE) as shell:
             self.wait_for_proc_cmdline(shell.pid)
             pr = apport.report.Report()
@@ -204,9 +204,7 @@ class T(unittest.TestCase):
         )
 
         # check correct handling of interpreted executables: shell
-        with subprocess.Popen(
-            ["zgrep", "foo"], stdin=subprocess.PIPE
-        ) as zgrep:
+        with subprocess.Popen(["zgrep", "foo"], stdin=subprocess.PIPE) as zgrep:
             self.wait_for_proc_cmdline(zgrep.pid)
             pr = apport.report.Report()
             pr.add_proc_info(pid=zgrep.pid)
@@ -214,12 +212,10 @@ class T(unittest.TestCase):
         self.assertTrue(pr["ExecutablePath"].endswith("bin/zgrep"))
         with open(pr["ExecutablePath"], encoding="utf-8") as fd:
             self.assertEqual(
-                pr["InterpreterPath"],
-                os.path.realpath(fd.readline().strip()[2:]),
+                pr["InterpreterPath"], os.path.realpath(fd.readline().strip()[2:])
             )
         self.assertEqual(
-            int(pr["ExecutableTimestamp"]),
-            int(os.stat(pr["ExecutablePath"]).st_mtime),
+            int(pr["ExecutableTimestamp"]), int(os.stat(pr["ExecutablePath"]).st_mtime)
         )
         self.assertIn("[stack]", pr["ProcMaps"])
 
@@ -343,6 +339,8 @@ class T(unittest.TestCase):
         self.assertIn("PATH=(custom, user)", r["ProcEnviron"])
 
     def test_check_interpreted(self):
+        # TODO: Split into separate test cases
+        # pylint: disable=too-many-statements
         """_check_interpreted()."""
         restore_root = False
         if os.getuid() == 0:
@@ -544,8 +542,7 @@ class T(unittest.TestCase):
         finally:
             sys.argv = orig_argv
         self.assertTrue(
-            pr["ExecutablePath"].endswith("unittest/__main__.py"),
-            pr["ExecutablePath"],
+            pr["ExecutablePath"].endswith("unittest/__main__.py"), pr["ExecutablePath"]
         )
         self.assertEqual(pr["InterpreterPath"], "/usr/bin/python")
         self.assertNotIn("UnreportableReason", pr)
@@ -563,9 +560,7 @@ class T(unittest.TestCase):
             "\0/var/log/nanny.log\0-y\0/usr/share/nanny/daemon/nanny.tap"
         )
         pr._check_interpreted()
-        self.assertEqual(
-            pr["ExecutablePath"], "/usr/share/nanny/daemon/nanny.tap"
-        )
+        self.assertEqual(pr["ExecutablePath"], "/usr/share/nanny/daemon/nanny.tap")
         self.assertEqual(pr["InterpreterPath"], "/usr/bin/twistd")
 
         # LP#625039
@@ -593,8 +588,7 @@ class T(unittest.TestCase):
         )
         pr._check_interpreted()
         self.assertEqual(
-            pr["ExecutablePath"],
-            "/usr/share/vodafone-mobile-connect/gtk-tap.py",
+            pr["ExecutablePath"], "/usr/share/vodafone-mobile-connect/gtk-tap.py"
         )
         self.assertEqual(pr["InterpreterPath"], "/usr/bin/twistd")
 
@@ -650,9 +644,7 @@ int main() { return f(42); }
                 fd.write(code)
             try:
                 subprocess.run(
-                    ["gcc"]
-                    + extra_gcc_args
-                    + ["-g", "crash.c", "-o", "crash"],
+                    ["gcc"] + extra_gcc_args + ["-g", "crash.c", "-o", "crash"],
                     check=True,
                 )
             except FileNotFoundError as error:
@@ -701,9 +693,7 @@ int main() { return f(42); }
             time.sleep(0.5)
             count += 1
         assert os.path.exists(core_path)
-        subprocess.run(
-            ["readelf", "-n", core_path], check=True, stdout=subprocess.PIPE
-        )
+        subprocess.run(["readelf", "-n", core_path], check=True, stdout=subprocess.PIPE)
 
     def _validate_gdb_fields(self, pr):
         self.assertIn("Stacktrace", pr)
@@ -782,8 +772,7 @@ int main() { return f(42); }
         self.assertNotIn("Stacktrace", pr)
         self.assertNotIn("StacktraceTop", pr)
         self.assertIn(
-            "not a core dump: file format not recognized",
-            pr["UnreportableReason"],
+            "not a core dump: file format not recognized", pr["UnreportableReason"]
         )
 
     def test_add_gdb_info_short_core_file(self):
@@ -803,9 +792,7 @@ int main() { return f(42); }
 
         self.assertNotIn("Stacktrace", pr)
         self.assertNotIn("StacktraceTop", pr)
-        self.assertTrue(
-            pr["UnreportableReason"].startswith("Invalid core dump")
-        )
+        self.assertTrue(pr["UnreportableReason"].startswith("Invalid core dump"))
 
     @unittest.mock.patch("gzip.GzipFile.read")
     def test_add_gdb_info_damaged_gz_core(self, mock_gzread):
@@ -820,8 +807,7 @@ int main() { return f(42); }
         with open(core, "rb") as f:
             pr["CoreDump"] = problem_report.CompressedValue(f.read())
         mock_gzread.side_effect = EOFError(
-            "Compressed file ended before the "
-            "end-of-stream marker was reached"
+            "Compressed file ended before the end-of-stream marker was reached"
         )
         self.assertRaises(EOFError, pr.add_gdb_info)
         self.assertTrue(mock_gzread.called)
@@ -859,23 +845,18 @@ int main() { return f(42); }
                 pr.load(f)
         pr.add_hooks_info()
         self.assertIn(
-            'Skipped: missing required field "Architecture"',
-            pr["SegvAnalysis"],
+            'Skipped: missing required field "Architecture"', pr["SegvAnalysis"]
         )
 
         pr.add_os_info()
         pr.add_hooks_info()
-        self.assertIn(
-            'Skipped: missing required field "ProcMaps"', pr["SegvAnalysis"]
-        )
+        self.assertIn('Skipped: missing required field "ProcMaps"', pr["SegvAnalysis"])
 
         pr.add_proc_info()
         pr.add_hooks_info()
         if pr["Architecture"] in ["amd64", "i386"]:
             # data/general-hooks/parse_segv.py only runs for x86 and x86_64
-            self.assertIn(
-                "not located in a known VMA region", pr["SegvAnalysis"]
-            )
+            self.assertIn("not located in a known VMA region", pr["SegvAnalysis"])
 
     def test_add_gdb_info_script(self):
         """add_gdb_info() with a script."""
@@ -948,16 +929,11 @@ int main() { return f(42); }
         )
         self._validate_gdb_fields(pr)
         self.assertIn(
-            "crash.c:2: main: Assertion `1 < 0' failed.",
-            pr["AssertionMessage"],
-        )
-        self.assertFalse(
-            pr["AssertionMessage"].startswith("$"), pr["AssertionMessage"]
+            "crash.c:2: main: Assertion `1 < 0' failed.", pr["AssertionMessage"]
         )
+        self.assertFalse(pr["AssertionMessage"].startswith("$"), pr["AssertionMessage"])
         self.assertNotIn("= 0x", pr["AssertionMessage"])
-        self.assertFalse(
-            pr["AssertionMessage"].endswith("\\n"), pr["AssertionMessage"]
-        )
+        self.assertFalse(pr["AssertionMessage"].endswith("\\n"), pr["AssertionMessage"])
 
         # abort with internal error
         pr = self._generate_sigsegv_report(
@@ -976,16 +952,11 @@ int main() { return f(42); }
         )
         self._validate_gdb_fields(pr)
         self.assertIn(
-            "** buffer overflow detected ***: terminated",
-            pr["AssertionMessage"],
-        )
-        self.assertFalse(
-            pr["AssertionMessage"].startswith("$"), pr["AssertionMessage"]
+            "** buffer overflow detected ***: terminated", pr["AssertionMessage"]
         )
+        self.assertFalse(pr["AssertionMessage"].startswith("$"), pr["AssertionMessage"])
         self.assertNotIn("= 0x", pr["AssertionMessage"])
-        self.assertFalse(
-            pr["AssertionMessage"].endswith("\\n"), pr["AssertionMessage"]
-        )
+        self.assertFalse(pr["AssertionMessage"].endswith("\\n"), pr["AssertionMessage"])
 
         # abort without assertion
         pr = self._generate_sigsegv_report(
@@ -1082,11 +1053,11 @@ int main() { return f(42); }
             os.unlink("core")
 
         self._validate_gdb_fields(pr)
-        self.assertIn(
-            "Assertion failed in main: 1 < 0", pr["AssertionMessage"]
-        )
+        self.assertIn("Assertion failed in main: 1 < 0", pr["AssertionMessage"])
 
     def test_search_bug_patterns(self):
+        # TODO: Split into separate test cases
+        # pylint: disable=too-many-statements
         """search_bug_patterns()."""
         # create some test patterns
         patterns = textwrap.dedent(
@@ -1153,13 +1124,11 @@ int main() { return f(42); }
 
             # positive match cases
             self.assertEqual(
-                r_bash.search_bug_patterns(pattern_url),
-                "http://bugtracker.net/bugs/1",
+                r_bash.search_bug_patterns(pattern_url), "http://bugtracker.net/bugs/1"
             )
             r_bash["Foo"] = "write_goodbye"
             self.assertEqual(
-                r_bash.search_bug_patterns(pattern_url),
-                "http://bugtracker.net/bugs/2",
+                r_bash.search_bug_patterns(pattern_url), "http://bugtracker.net/bugs/2"
             )
             self.assertEqual(
                 r_coreutils.search_bug_patterns(pattern_url),
@@ -1176,9 +1145,7 @@ int main() { return f(42); }
 
             # also works for CompressedValues
             r_bash_compressed = r_bash.copy()
-            r_bash_compressed["Foo"] = problem_report.CompressedValue(
-                b"bazaar"
-            )
+            r_bash_compressed["Foo"] = problem_report.CompressedValue(b"bazaar")
             self.assertEqual(
                 r_bash_compressed.search_bug_patterns(pattern_url),
                 "http://bugtracker.net/bugs/1",
@@ -1275,6 +1242,8 @@ int main() { return f(42); }
         )
 
     def test_add_hooks_info(self):
+        # TODO: Split into separate test cases
+        # pylint: disable=too-many-statements
         """add_hooks_info()."""
         orig_general_hook_dir = apport.report.GENERAL_HOOK_DIR
         apport.report.GENERAL_HOOK_DIR = tempfile.mkdtemp()
@@ -1522,9 +1491,7 @@ int main() { return f(42); }
             )
             os.makedirs(opt_hook_dir)
             with open(
-                os.path.join(opt_hook_dir, "source_foo.py"),
-                "w",
-                encoding="utf-8",
+                os.path.join(opt_hook_dir, "source_foo.py"), "w", encoding="utf-8"
             ) as fd:
                 fd.write(
                     textwrap.dedent(
@@ -1549,9 +1516,9 @@ int main() { return f(42); }
             r = apport.report.Report()
             r["Package"] = "foo-bin 0.2"
             r["SourcePackage"] = "foo"
-            r["ExecutablePath"] = (
-                "%s/foolabs.example.com/foo/bin/frob" % apport.report._opt_dir
-            )
+            r[
+                "ExecutablePath"
+            ] = f"{apport.report._opt_dir}/foolabs.example.com/foo/bin/frob"
 
             self.assertEqual(r.add_hooks_info(), False)
             self.assertEqual(r["SourceHook"], "1")
@@ -1636,17 +1603,11 @@ int main() { return f(42); }
         """mark_ignore() and check_ignored()."""
         orig_ignore_file = apport.report.apport.report._ignore_file
         workdir = tempfile.mkdtemp()
-        apport.report.apport.report._ignore_file = os.path.join(
-            workdir, "ignore.xml"
-        )
+        apport.report.apport.report._ignore_file = os.path.join(workdir, "ignore.xml")
         try:
-            with open(
-                os.path.join(workdir, "bash"), "w", encoding="utf-8"
-            ) as fd:
+            with open(os.path.join(workdir, "bash"), "w", encoding="utf-8") as fd:
                 fd.write("bash")
-            with open(
-                os.path.join(workdir, "crap"), "w", encoding="utf-8"
-            ) as fd:
+            with open(os.path.join(workdir, "crap"), "w", encoding="utf-8") as fd:
                 fd.write("crap")
 
             bash_rep = apport.report.Report()
@@ -1676,9 +1637,7 @@ int main() { return f(42); }
 
             # poke crap so that it has a newer timestamp
             time.sleep(1)
-            with open(
-                os.path.join(workdir, "crap"), "w", encoding="utf-8"
-            ) as fd:
+            with open(os.path.join(workdir, "crap"), "w", encoding="utf-8") as fd:
                 fd.write("crapnew")
             self.assertEqual(bash_rep.check_ignored(), True)
             self.assertEqual(crap_rep.check_ignored(), False)
@@ -1708,7 +1667,7 @@ int main() { return f(42); }
         orig_denylist_dir = apport.report._DENYLIST_DIR
         apport.report._DENYLIST_DIR = tempfile.mkdtemp()
         orig_ignore_file = apport.report._ignore_file
-        apport.report._ignore_file = "/nonexistant"
+        apport.report._ignore_file = "/nonexistent"
         try:
             bash_rep = apport.report.Report()
             bash_rep["ExecutablePath"] = "/bin/bash"
@@ -1729,9 +1688,7 @@ int main() { return f(42); }
 
             # no ignores on nonmatching paths
             with open(
-                os.path.join(apport.report._DENYLIST_DIR, "bl1"),
-                "w",
-                encoding="utf-8",
+                os.path.join(apport.report._DENYLIST_DIR, "bl1"), "w", encoding="utf-8"
             ) as fd:
                 fd.write("/bin/bas\n/bin/bashh\nbash\nbin/bash\n")
             self.assertEqual(bash_rep.check_ignored(), False)
@@ -1739,9 +1696,7 @@ int main() { return f(42); }
 
             # ignore crap now
             with open(
-                os.path.join(apport.report._DENYLIST_DIR, "bl_2"),
-                "w",
-                encoding="utf-8",
+                os.path.join(apport.report._DENYLIST_DIR, "bl_2"), "w", encoding="utf-8"
             ) as fd:
                 fd.write("/bin/crap\n")
             self.assertEqual(bash_rep.check_ignored(), False)
@@ -1749,9 +1704,7 @@ int main() { return f(42); }
 
             # ignore bash now
             with open(
-                os.path.join(apport.report._DENYLIST_DIR, "bl1"),
-                "a",
-                encoding="utf-8",
+                os.path.join(apport.report._DENYLIST_DIR, "bl1"), "a", encoding="utf-8"
             ) as fd:
                 fd.write("/bin/bash\n")
             self.assertEqual(bash_rep.check_ignored(), True)
@@ -1766,7 +1719,7 @@ int main() { return f(42); }
         orig_allowlist_dir = apport.report._ALLOWLIST_DIR
         apport.report._ALLOWLIST_DIR = tempfile.mkdtemp()
         orig_ignore_file = apport.report.apport.report._ignore_file
-        apport.report.apport.report._ignore_file = "/nonexistant"
+        apport.report.apport.report._ignore_file = "/nonexistent"
         try:
             bash_rep = apport.report.Report()
             bash_rep["ExecutablePath"] = "/bin/bash"
@@ -1787,9 +1740,7 @@ int main() { return f(42); }
 
             # accepts matching paths
             with open(
-                os.path.join(apport.report._ALLOWLIST_DIR, "wl1"),
-                "w",
-                encoding="utf-8",
+                os.path.join(apport.report._ALLOWLIST_DIR, "wl1"), "w", encoding="utf-8"
             ) as fd:
                 fd.write("/bin/bash\n")
             self.assertEqual(bash_rep.check_ignored(), False)
@@ -1807,9 +1758,7 @@ int main() { return f(42); }
 
             # only complete matches accepted
             with open(
-                os.path.join(apport.report._ALLOWLIST_DIR, "wl1"),
-                "w",
-                encoding="utf-8",
+                os.path.join(apport.report._ALLOWLIST_DIR, "wl1"), "w", encoding="utf-8"
             ) as fd:
                 fd.write("/bin/bas\n/bin/bashh\nbash\n")
             self.assertEqual(bash_rep.check_ignored(), True)
@@ -1829,23 +1778,22 @@ int main() { return f(42); }
         self.assertEqual(report.obsolete_packages(), ["bash"])
         report["Package"] = "bash 0 [modified: /bin/bash]"
         self.assertEqual(report.obsolete_packages(), ["bash"])
-        report["Package"] = "bash " + apport.packaging.get_available_version(
-            "bash"
-        )
+        report["Package"] = "bash " + apport.packaging.get_available_version("bash")
         self.assertEqual(report.obsolete_packages(), [])
 
         report["Dependencies"] = "coreutils 0\ncron 0\n"
         self.assertEqual(report.obsolete_packages(), ["coreutils", "cron"])
 
         report["Dependencies"] = (
-            "coreutils %s [modified: /bin/mount]\ncron 0\n"
-            % apport.packaging.get_available_version("coreutils")
+            f"coreutils {apport.packaging.get_available_version('coreutils')}"
+            f" [modified: /bin/mount]\ncron 0\n"
         )
         self.assertEqual(report.obsolete_packages(), ["cron"])
 
-        report["Dependencies"] = "coreutils %s\ncron %s\n" % (
-            apport.packaging.get_available_version("coreutils"),
-            apport.packaging.get_available_version("cron"),
+        report["Dependencies"] = (
+            f"coreutils"
+            f" {apport.packaging.get_available_version('coreutils')}\n"
+            f"cron {apport.packaging.get_available_version('cron')}\n"
         )
         self.assertEqual(report.obsolete_packages(), [])
 
@@ -1856,9 +1804,7 @@ int main() { return f(42); }
         pr = apport.report.Report()
         pr.add_proc_info()
         self.assertEqual(pr._address_to_offset(0), None)
-        res = pr._address_to_offset(
-            int(pr["ProcMaps"].split("-", 1)[0], 16) + 5
-        )
+        res = pr._address_to_offset(int(pr["ProcMaps"].split("-", 1)[0], 16) + 5)
         self.assertEqual(res.split("+", 1)[1], "5")
         self.assertIn("python", res.split("+", 1)[0])
 
@@ -1884,7 +1830,7 @@ int main() { return f(42); }
 
     def test_get_logind_session_fd(self):
         proc_pid_fd = os.open(
-            "/proc/%s" % os.getpid(), os.O_RDONLY | os.O_PATH | os.O_DIRECTORY
+            f"/proc/{os.getpid()}", os.O_RDONLY | os.O_PATH | os.O_DIRECTORY
         )
         self.addCleanup(os.close, proc_pid_fd)
         ret = apport.Report.get_logind_session(proc_pid_fd=proc_pid_fd)
@@ -1915,6 +1861,18 @@ int main() { return f(42); }
         out = apport.report._command_output(["env"], env=fake_env)
         self.assertIn("GCONV_PATH", out)
 
+    def test_command_output_timeout(self):
+        with self.assertRaisesRegex(OSError, "timed out after 0.1 seconds: fail$"):
+            apport.report._command_output(
+                ["sh", "-c", "echo fail; sleep 3600"], timeout=0.1
+            )
+
+    def test_command_output_timeout_no_output(self):
+        with self.assertRaisesRegex(
+            OSError, "timed out after 0.1 seconds with no stdout"
+        ):
+            apport.report._command_output(["sleep", "3600"], timeout=0.1)
+
     def test_command_output_raises_error(self):
         with self.assertRaisesRegex(OSError, "failed with exit code 1"):
             apport.report._command_output(["false"])
