@@ -9,22 +9,25 @@
 
 """Command line Apport user interface tests."""
 
+import io
 import os
 import pathlib
 import unittest
+from gettext import gettext as _
 
 import apport.report
 from tests.helper import import_module_from_file, skip_if_command_is_missing
 from tests.paths import is_local_source_directory, local_test_environment
 
 if is_local_source_directory():
-    apport_cli_path = "bin/apport-cli"
+    APPORT_CLI_PATH = "bin/apport-cli"
 else:
-    apport_cli_path = "/usr/bin/apport-cli"
-apport_cli = import_module_from_file(pathlib.Path(apport_cli_path))
+    APPORT_CLI_PATH = "/usr/bin/apport-cli"
+apport_cli = import_module_from_file(pathlib.Path(APPORT_CLI_PATH))
 
 
 class TestApportCli(unittest.TestCase):
+    # pylint: disable=missing-function-docstring
     """Test apport-cli."""
 
     @classmethod
@@ -38,7 +41,7 @@ class TestApportCli(unittest.TestCase):
         os.environ.update(cls.orig_environ)
 
     def setUp(self):
-        self.app = apport_cli.CLIUserInterface([apport_cli_path])
+        self.app = apport_cli.CLIUserInterface([APPORT_CLI_PATH])
         self.app.report = apport.report.Report()
         self.app.report.add_os_info()
         self.app.report["ExecutablePath"] = "/bin/bash"
@@ -61,3 +64,11 @@ class TestApportCli(unittest.TestCase):
             "11\n\n",
             report,
         )
+
+    @unittest.mock.patch("sys.stdout", new_callable=io.StringIO)
+    def test_save_report_in_temp_directory(self, stdout_mock: io.StringIO) -> None:
+        self.app.report["Package"] = "bash"
+        with unittest.mock.patch.object(apport_cli.CLIDialog, "run") as run_mock:
+            run_mock.return_value = 4
+            self.app.ui_present_report_details()
+        self.assertIn(_("Problem report file:"), stdout_mock.getvalue())
