@@ -1,5 +1,3 @@
-# Test apport_python_hook.py
-#
 # Copyright (c) 2006 - 2011 Canonical Ltd.
 # Authors: Robert Collins <robert@ubuntu.com>
 #          Martin Pitt <martin.pitt@ubuntu.com>
@@ -10,6 +8,11 @@
 # option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
 # the full text of the license.
 
+"""Test apport_python_hook.py"""
+
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import atexit
 import os
 import shutil
@@ -32,6 +35,8 @@ from tests.paths import local_test_environment
 
 @unittest.skipUnless(HAS_DBUS, "dbus Python module not installed")
 class T(unittest.TestCase):
+    """Test apport_python_hook.py"""
+
     @classmethod
     def setUpClass(cls):
         cls.env = os.environ | local_test_environment()
@@ -109,15 +114,10 @@ func(42)
         )
 
         pr = self._load_report()
-        self.assertTrue(
-            pr["Traceback"].startswith("Traceback"), pr["Traceback"]
-        )
-        self.assertIn(
-            "org.freedesktop.DBus.Error.ServiceUnknown", pr["Traceback"]
-        )
+        self.assertTrue(pr["Traceback"].startswith("Traceback"), pr["Traceback"])
+        self.assertIn("org.freedesktop.DBus.Error.ServiceUnknown", pr["Traceback"])
         self.assertEqual(
-            pr["DbusErrorAnalysis"],
-            "no service file providing com.example.NotExisting",
+            pr["DbusErrorAnalysis"], "no service file providing com.example.NotExisting"
         )
 
     def test_dbus_service_unknown_wrongbus_notrunning(self):
@@ -136,9 +136,7 @@ func(42)
         )
 
         pr = self._load_report()
-        self.assertIn(
-            "org.freedesktop.DBus.Error.ServiceUnknown", pr["Traceback"]
-        )
+        self.assertIn("org.freedesktop.DBus.Error.ServiceUnknown", pr["Traceback"])
         self.assertRegex(
             pr["DbusErrorAnalysis"],
             "^provided by .*/dbus-1/services.*vfs.*[mM]etadata.service",
@@ -165,9 +163,7 @@ func(42)
         )
 
         pr = self._load_report()
-        self.assertIn(
-            "org.freedesktop.DBus.Error.ServiceUnknown", pr["Traceback"]
-        )
+        self.assertIn("org.freedesktop.DBus.Error.ServiceUnknown", pr["Traceback"])
         self.assertRegex(
             pr["DbusErrorAnalysis"],
             "^provided by .*/dbus-1/services.*vfs.*[mM]etadata.service",
@@ -224,12 +220,8 @@ func(42)
         )
 
         pr = self._load_report()
-        self.assertTrue(
-            pr["Traceback"].startswith("Traceback"), pr["Traceback"]
-        )
-        self.assertIn(
-            "org.freedesktop.DBus.Error.UnknownMethod", pr["Traceback"]
-        )
+        self.assertTrue(pr["Traceback"].startswith("Traceback"), pr["Traceback"])
+        self.assertIn("org.freedesktop.DBus.Error.UnknownMethod", pr["Traceback"])
         self.assertNotIn("DbusErrorAnalysis", pr)
         # we expect it to unwrap the actual exception from the DBusException
         self.assertIn(
@@ -241,9 +233,7 @@ func(42)
     def _load_report(self):
         """Ensure that there is exactly one crash report and load it."""
         reports = apport.fileutils.get_new_reports()
-        self.assertEqual(
-            len(reports), 1, "crashed Python program produced a report"
-        )
+        self.assertEqual(len(reports), 1, "crashed Python program produced a report")
         pr = apport.Report()
         with open(reports[0], "rb") as f:
             pr.load(f)
