@@ -9,6 +9,10 @@
 # option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
 # the full text of the license.
 
+# pylint: disable=too-many-lines
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import os
 import shutil
 import subprocess
@@ -46,10 +50,9 @@ else:
     GTKUserInterface = None
 
 
-@unittest.skipIf(
-    GI_IMPORT_ERROR, f"gi Python module not available: {GI_IMPORT_ERROR}"
-)
-class T(unittest.TestCase):
+@unittest.skipIf(GI_IMPORT_ERROR, f"gi Python module not available: {GI_IMPORT_ERROR}")
+class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
+    # pylint: disable=missing-class-docstring,missing-function-docstring
     POLLING_INTERVAL_MS = 10
 
     @classmethod
@@ -126,16 +129,12 @@ class T(unittest.TestCase):
         self.app.report["ProblemType"] = "KernelCrash"
         GLib.idle_add(Gtk.main_quit)
         self.app.ui_present_report_details(True)
-        self.assertEqual(
-            self.app.w("dialog_crash_new").get_title(), self.distro
-        )
+        self.assertEqual(self.app.w("dialog_crash_new").get_title(), self.distro)
         self.assertEqual(
             self.app.w("title_label").get_text(),
             _("Sorry, %s has experienced an internal error.") % self.distro,
         )
-        self.assertTrue(
-            self.app.w("send_problem_notice_label").get_property("visible")
-        )
+        self.assertTrue(self.app.w("send_problem_notice_label").get_property("visible"))
         remember_send_error_report = self.app.w("remember_send_report_choice")
         self.assertTrue(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
@@ -144,9 +143,7 @@ class T(unittest.TestCase):
         self.assertTrue(self.app.w("continue_button").get_property("visible"))
         self.assertEqual(self.app.w("continue_button").get_label(), _("Send"))
         self.assertFalse(self.app.w("subtitle_label").get_property("visible"))
-        self.assertFalse(
-            self.app.w("ignore_future_problems").get_property("visible")
-        )
+        self.assertFalse(self.app.w("ignore_future_problems").get_property("visible"))
 
     def test_package_crash_layout(self):
         """Display crash dialog for a failed package installation.
@@ -165,16 +162,12 @@ class T(unittest.TestCase):
         self.app.report["Package"] = "apport 1.2.3~0ubuntu1"
         GLib.idle_add(Gtk.main_quit)
         self.app.ui_present_report_details(True)
-        self.assertEqual(
-            self.app.w("dialog_crash_new").get_title(), self.distro
-        )
+        self.assertEqual(self.app.w("dialog_crash_new").get_title(), self.distro)
         self.assertEqual(
             self.app.w("title_label").get_text(),
             _("Sorry, a problem occurred while installing software."),
         )
-        self.assertTrue(
-            self.app.w("send_problem_notice_label").get_property("visible")
-        )
+        self.assertTrue(self.app.w("send_problem_notice_label").get_property("visible"))
         remember_send_error_report = self.app.w("remember_send_report_choice")
         self.assertTrue(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
@@ -184,8 +177,7 @@ class T(unittest.TestCase):
         self.assertEqual(self.app.w("continue_button").get_label(), _("Send"))
         self.assertTrue(self.app.w("subtitle_label").get_property("visible"))
         self.assertEqual(
-            self.app.w("subtitle_label").get_text(),
-            _("Package: apport 1.2.3~0ubuntu1"),
+            self.app.w("subtitle_label").get_text(), _("Package: apport 1.2.3~0ubuntu1")
         )
 
     def test_regular_crash_thread_layout(self):
@@ -240,16 +232,12 @@ class T(unittest.TestCase):
             self.app.report["DesktopFile"] = fp.name
             GLib.idle_add(Gtk.main_quit)
             self.app.ui_present_report_details(True)
-        self.assertEqual(
-            self.app.w("dialog_crash_new").get_title(), self.distro
-        )
+        self.assertEqual(self.app.w("dialog_crash_new").get_title(), self.distro)
         self.assertEqual(
             self.app.w("title_label").get_text(),
             _("The application Apport has closed unexpectedly."),
         )
-        self.assertTrue(
-            self.app.w("send_problem_notice_label").get_property("visible")
-        )
+        self.assertTrue(self.app.w("send_problem_notice_label").get_property("visible"))
         remember_send_error_report = self.app.w("remember_send_report_choice")
         self.assertTrue(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
@@ -259,9 +247,7 @@ class T(unittest.TestCase):
         self.assertTrue(self.app.w("continue_button").get_property("visible"))
         self.assertEqual(self.app.w("continue_button").get_label(), _("Send"))
         self.assertFalse(self.app.w("subtitle_label").get_property("visible"))
-        self.assertTrue(
-            self.app.w("ignore_future_problems").get_property("visible")
-        )
+        self.assertTrue(self.app.w("ignore_future_problems").get_property("visible"))
         self.assertTrue(
             self.app.w("ignore_future_problems")
             .get_label()
@@ -303,16 +289,12 @@ class T(unittest.TestCase):
             self.app.report["DesktopFile"] = fp.name
             GLib.idle_add(Gtk.main_quit)
             self.app.ui_present_report_details(True)
-        self.assertEqual(
-            self.app.w("dialog_crash_new").get_title(), self.distro
-        )
+        self.assertEqual(self.app.w("dialog_crash_new").get_title(), self.distro)
         self.assertEqual(
             self.app.w("title_label").get_text(),
             _("The application Apport has closed unexpectedly."),
         )
-        self.assertTrue(
-            self.app.w("send_problem_notice_label").get_property("visible")
-        )
+        self.assertTrue(self.app.w("send_problem_notice_label").get_property("visible"))
         remember_send_error_report = self.app.w("remember_send_report_choice")
         self.assertTrue(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
@@ -321,9 +303,7 @@ class T(unittest.TestCase):
         self.assertTrue(self.app.w("continue_button").get_property("visible"))
         self.assertEqual(self.app.w("continue_button").get_label(), _("Send"))
         self.assertFalse(self.app.w("subtitle_label").get_property("visible"))
-        self.assertTrue(
-            self.app.w("ignore_future_problems").get_property("visible")
-        )
+        self.assertTrue(self.app.w("ignore_future_problems").get_property("visible"))
         self.assertTrue(
             self.app.w("ignore_future_problems")
             .get_label()
@@ -366,16 +346,12 @@ class T(unittest.TestCase):
             self.app.report["DesktopFile"] = fp.name
             GLib.idle_add(Gtk.main_quit)
             self.app.ui_present_report_details(True)
-        self.assertEqual(
-            self.app.w("dialog_crash_new").get_title(), self.distro
-        )
+        self.assertEqual(self.app.w("dialog_crash_new").get_title(), self.distro)
         self.assertEqual(
             self.app.w("title_label").get_text(),
             _("The application Apport has closed unexpectedly."),
         )
-        self.assertTrue(
-            self.app.w("send_problem_notice_label").get_property("visible")
-        )
+        self.assertTrue(self.app.w("send_problem_notice_label").get_property("visible"))
         remember_send_error_report = self.app.w("remember_send_report_choice")
         self.assertTrue(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
@@ -419,23 +395,16 @@ class T(unittest.TestCase):
             self.app.report["DesktopFile"] = fp.name
             GLib.idle_add(Gtk.main_quit)
             self.app.ui_present_report_details(True)
-        self.assertEqual(
-            self.app.w("dialog_crash_new").get_title(), self.distro
-        )
+        self.assertEqual(self.app.w("dialog_crash_new").get_title(), self.distro)
         self.assertEqual(
             self.app.w("title_label").get_text(),
             _("The application Apport has stopped responding."),
         )
         self.assertEqual(
             self.app.w("subtitle_label").get_text(),
-            _(
-                "You can wait to see if it wakes up, or close or "
-                "relaunch it."
-            ),
-        )
-        self.assertTrue(
-            self.app.w("send_problem_notice_label").get_property("visible")
+            _("You can wait to see if it wakes up, or close or relaunch it."),
         )
+        self.assertTrue(self.app.w("send_problem_notice_label").get_property("visible"))
         remember_send_error_report = self.app.w("remember_send_report_choice")
         self.assertTrue(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
@@ -444,9 +413,7 @@ class T(unittest.TestCase):
         self.assertTrue(self.app.w("continue_button").get_property("visible"))
         self.assertEqual(self.app.w("continue_button").get_label(), _("Send"))
         self.assertTrue(self.app.w("subtitle_label").get_property("visible"))
-        self.assertFalse(
-            self.app.w("ignore_future_problems").get_property("visible")
-        )
+        self.assertFalse(self.app.w("ignore_future_problems").get_property("visible"))
 
     def test_system_crash_layout(self):
         """Display crash dialog for a system application crash.
@@ -468,9 +435,7 @@ class T(unittest.TestCase):
         self.app.report["Package"] = "bash 5"
         GLib.idle_add(Gtk.main_quit)
         self.app.ui_present_report_details(True)
-        self.assertEqual(
-            self.app.w("dialog_crash_new").get_title(), self.distro
-        )
+        self.assertEqual(self.app.w("dialog_crash_new").get_title(), self.distro)
         self.assertEqual(
             self.app.w("title_label").get_text(),
             _("Sorry, %s has experienced an internal error.") % self.distro,
@@ -480,9 +445,7 @@ class T(unittest.TestCase):
             _("If you notice further problems, try restarting the computer."),
         )
         self.assertTrue(self.app.w("subtitle_label").get_property("visible"))
-        self.assertTrue(
-            self.app.w("send_problem_notice_label").get_property("visible")
-        )
+        self.assertTrue(self.app.w("send_problem_notice_label").get_property("visible"))
         remember_send_error_report = self.app.w("remember_send_report_choice")
         self.assertTrue(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
@@ -490,13 +453,9 @@ class T(unittest.TestCase):
         self.assertTrue(self.app.w("dont_send_button").get_property("visible"))
         self.assertTrue(self.app.w("continue_button").get_property("visible"))
         self.assertEqual(self.app.w("continue_button").get_label(), _("Send"))
+        self.assertTrue(self.app.w("ignore_future_problems").get_property("visible"))
         self.assertTrue(
-            self.app.w("ignore_future_problems").get_property("visible")
-        )
-        self.assertTrue(
-            self.app.w("ignore_future_problems")
-            .get_label()
-            .endswith("of this type")
+            self.app.w("ignore_future_problems").get_label().endswith("of this type")
         )
 
     def test_system_crash_from_console_layout(self):
@@ -515,17 +474,13 @@ class T(unittest.TestCase):
         """
         self.app.report["ProblemType"] = "Crash"
         self.app.report["Package"] = "bash 5"
-        self.app.report[
-            "ProcEnviron"
-        ] = "LANGUAGE=en_GB:en\nSHELL=/bin/sh\nTERM=xterm"
+        self.app.report["ProcEnviron"] = "LANGUAGE=en_GB:en\nSHELL=/bin/sh\nTERM=xterm"
         self.app.report["ExecutablePath"] = "/usr/bin/apport"
         # This will be set by apport/ui.py in load_report()
         self.app.cur_package = "apport"
         GLib.idle_add(Gtk.main_quit)
         self.app.ui_present_report_details(True)
-        self.assertEqual(
-            self.app.w("dialog_crash_new").get_title(), self.distro
-        )
+        self.assertEqual(self.app.w("dialog_crash_new").get_title(), self.distro)
         self.assertEqual(
             self.app.w("title_label").get_text(),
             _("Sorry, the application apport has stopped unexpectedly."),
@@ -535,9 +490,7 @@ class T(unittest.TestCase):
             _("If you notice further problems, try restarting the computer."),
         )
         self.assertTrue(self.app.w("subtitle_label").get_property("visible"))
-        self.assertTrue(
-            self.app.w("send_problem_notice_label").get_property("visible")
-        )
+        self.assertTrue(self.app.w("send_problem_notice_label").get_property("visible"))
         remember_send_error_report = self.app.w("remember_send_report_choice")
         self.assertTrue(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
@@ -555,9 +508,7 @@ class T(unittest.TestCase):
         )
 
         # no crash counter
-        self.assertFalse(
-            self.app.w("ignore_future_problems").get_property("visible")
-        )
+        self.assertFalse(self.app.w("ignore_future_problems").get_property("visible"))
 
     @unittest.mock.patch.object(
         GTKUserInterface, "can_examine_locally", unittest.mock.MagicMock()
@@ -620,9 +571,7 @@ class T(unittest.TestCase):
         self.assertTrue(self.app.w("continue_button").get_property("visible"))
         self.assertEqual(self.app.w("continue_button").get_label(), _("Send"))
         self.assertTrue(self.app.w("dont_send_button").get_property("visible"))
-        self.assertTrue(
-            self.app.w("details_scrolledwindow").get_property("visible")
-        )
+        self.assertTrue(self.app.w("details_scrolledwindow").get_property("visible"))
         self.assertTrue(self.app.w("dialog_crash_new").get_resizable())
 
     def test_apport_bug_package_layout_load_file(self):
@@ -649,9 +598,7 @@ class T(unittest.TestCase):
         self.assertTrue(self.app.w("continue_button").get_property("visible"))
         self.assertEqual(self.app.w("continue_button").get_label(), _("Send"))
         self.assertTrue(self.app.w("dont_send_button").get_property("visible"))
-        self.assertTrue(
-            self.app.w("details_scrolledwindow").get_property("visible")
-        )
+        self.assertTrue(self.app.w("details_scrolledwindow").get_property("visible"))
         self.assertTrue(self.app.w("dialog_crash_new").get_resizable())
 
     def test_recoverable_crash_layout(self):
@@ -685,17 +632,13 @@ class T(unittest.TestCase):
             self.app.report["DesktopFile"] = fp.name
             GLib.idle_add(Gtk.main_quit)
             self.app.ui_present_report_details(True)
-        self.assertEqual(
-            self.app.w("dialog_crash_new").get_title(), self.distro
-        )
+        self.assertEqual(self.app.w("dialog_crash_new").get_title(), self.distro)
         msg = "The application Apport has experienced an internal error."
         self.assertEqual(self.app.w("title_label").get_text(), msg)
         msg = "Some developer-specified error text."
         self.assertEqual(self.app.w("subtitle_label").get_text(), msg)
         self.assertTrue(self.app.w("subtitle_label").get_property("visible"))
-        self.assertTrue(
-            self.app.w("send_problem_notice_label").get_property("visible")
-        )
+        self.assertTrue(self.app.w("send_problem_notice_label").get_property("visible"))
         remember_send_error_report = self.app.w("remember_send_report_choice")
         self.assertTrue(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
@@ -713,21 +656,16 @@ class T(unittest.TestCase):
         self.assertFalse(remember_send_error_report.get_property("visible"))
         self.assertFalse(remember_send_error_report.get_active())
 
-    @unittest.mock.patch.object(
-        GTKUserInterface, "open_url", unittest.mock.MagicMock()
-    )
+    @unittest.mock.patch.object(GTKUserInterface, "open_url", unittest.mock.MagicMock())
     @unittest.mock.patch.object(
         GTKUserInterface, "ui_start_upload_progress", unittest.mock.MagicMock()
     )
     @unittest.mock.patch.object(
         GTKUserInterface, "ui_stop_upload_progress", unittest.mock.MagicMock()
     )
+    @unittest.mock.patch("apport.report.Report.add_gdb_info", unittest.mock.MagicMock())
     @unittest.mock.patch(
-        "apport.report.Report.add_gdb_info", unittest.mock.MagicMock()
-    )
-    @unittest.mock.patch(
-        "apport.fileutils.allowed_to_report",
-        unittest.mock.MagicMock(return_value=True),
+        "apport.fileutils.allowed_to_report", unittest.mock.MagicMock(return_value=True)
     )
     def test_crash_nodetails(self):
         """Crash report without showing details"""
@@ -767,21 +705,16 @@ class T(unittest.TestCase):
         # URL was opened
         self.assertEqual(self.app.open_url.call_count, 1)
 
-    @unittest.mock.patch.object(
-        GTKUserInterface, "open_url", unittest.mock.MagicMock()
-    )
+    @unittest.mock.patch.object(GTKUserInterface, "open_url", unittest.mock.MagicMock())
     @unittest.mock.patch.object(
         GTKUserInterface, "ui_start_upload_progress", unittest.mock.MagicMock()
     )
     @unittest.mock.patch.object(
         GTKUserInterface, "ui_stop_upload_progress", unittest.mock.MagicMock()
     )
+    @unittest.mock.patch("apport.report.Report.add_gdb_info", unittest.mock.MagicMock())
     @unittest.mock.patch(
-        "apport.report.Report.add_gdb_info", unittest.mock.MagicMock()
-    )
-    @unittest.mock.patch(
-        "apport.fileutils.allowed_to_report",
-        unittest.mock.MagicMock(return_value=True),
+        "apport.fileutils.allowed_to_report", unittest.mock.MagicMock(return_value=True)
     )
     def test_crash_details(self):
         """Crash report with showing details"""
@@ -833,9 +766,7 @@ class T(unittest.TestCase):
         # URL was opened
         self.assertEqual(self.app.open_url.call_count, 1)
 
-    @unittest.mock.patch.object(
-        GTKUserInterface, "open_url", unittest.mock.MagicMock()
-    )
+    @unittest.mock.patch.object(GTKUserInterface, "open_url", unittest.mock.MagicMock())
     @unittest.mock.patch.object(
         GTKUserInterface, "ui_start_upload_progress", unittest.mock.MagicMock()
     )
@@ -843,8 +774,7 @@ class T(unittest.TestCase):
         GTKUserInterface, "ui_stop_upload_progress", unittest.mock.MagicMock()
     )
     @unittest.mock.patch(
-        "apport.fileutils.allowed_to_report",
-        unittest.mock.MagicMock(return_value=True),
+        "apport.fileutils.allowed_to_report", unittest.mock.MagicMock(return_value=True)
     )
     def test_broken_crash_details(self):
         """Broken crash report with showing details."""
@@ -909,12 +839,9 @@ class T(unittest.TestCase):
         self.assertIn("cannot be reported", self.error_text)
         self.assertIn("decompressing", self.error_text)
 
-    @unittest.mock.patch.object(
-        GTKUserInterface, "open_url", unittest.mock.MagicMock()
-    )
+    @unittest.mock.patch.object(GTKUserInterface, "open_url", unittest.mock.MagicMock())
     @unittest.mock.patch(
-        "apport.fileutils.allowed_to_report",
-        unittest.mock.MagicMock(return_value=True),
+        "apport.fileutils.allowed_to_report", unittest.mock.MagicMock(return_value=True)
     )
     def test_crash_noaccept(self):
         """Crash report with non-accepting crash DB"""
@@ -949,12 +876,9 @@ class T(unittest.TestCase):
         self.assertTrue(r["Package"].startswith("bash "))
         self.assertIn("libc", r["Dependencies"])
 
-    @unittest.mock.patch.object(
-        GTKUserInterface, "open_url", unittest.mock.MagicMock()
-    )
+    @unittest.mock.patch.object(GTKUserInterface, "open_url", unittest.mock.MagicMock())
     @unittest.mock.patch(
-        "apport.fileutils.allowed_to_report",
-        unittest.mock.MagicMock(return_value=True),
+        "apport.fileutils.allowed_to_report", unittest.mock.MagicMock(return_value=True)
     )
     def test_kerneloops_nodetails(self):
         """Kernel oops report without showing details"""
@@ -1037,13 +961,9 @@ class T(unittest.TestCase):
         self.assertEqual(
             self.app.report["SourcePackage"], apport.packaging.get_source(pkg)
         )
-        self.assertEqual(
-            self.app.report["Package"], "%s (not installed)" % pkg
-        )
+        self.assertEqual(self.app.report["Package"], f"{pkg} (not installed)")
 
-    @unittest.mock.patch.object(
-        GTKUserInterface, "open_url", unittest.mock.MagicMock()
-    )
+    @unittest.mock.patch.object(GTKUserInterface, "open_url", unittest.mock.MagicMock())
     def test_update_report(self):
         """Updating an existing report."""
         self.app.report_file = None
@@ -1077,9 +997,7 @@ class T(unittest.TestCase):
         # No URL in this mode
         self.assertEqual(self.app.open_url.call_count, 0)
 
-    @unittest.mock.patch.object(
-        GTKUserInterface, "open_url", unittest.mock.MagicMock()
-    )
+    @unittest.mock.patch.object(GTKUserInterface, "open_url", unittest.mock.MagicMock())
     def test_update_report_different_binary_source(self):
         """Updating an existing report on a source package which does not have
         a binary of the same name"""
@@ -1100,7 +1018,7 @@ class T(unittest.TestCase):
 
         # create source package hook, as otherwise there is nothing to collect
         with open(
-            os.path.join(self.hook_dir, "source_%s.py" % source_pkg),
+            os.path.join(self.hook_dir, f"source_{source_pkg}.py"),
             "w",
             encoding="utf-8",
         ) as f:
@@ -1152,9 +1070,7 @@ class T(unittest.TestCase):
                 return True  # pragma: no cover
 
             data["orig_size"] = self.app.w("dialog_crash_new").get_size()
-            data["orig_resizable"] = self.app.w(
-                "dialog_crash_new"
-            ).get_resizable()
+            data["orig_resizable"] = self.app.w("dialog_crash_new").get_resizable()
             self.app.w("show_details").clicked()
             GLib.timeout_add(200, hide_details, data)
             return False
@@ -1165,9 +1081,7 @@ class T(unittest.TestCase):
                 return True  # pragma: no cover
 
             data["detail_size"] = self.app.w("dialog_crash_new").get_size()
-            data["detail_resizable"] = self.app.w(
-                "dialog_crash_new"
-            ).get_resizable()
+            data["detail_resizable"] = self.app.w("dialog_crash_new").get_resizable()
             self.app.w("show_details").clicked()
             GLib.timeout_add(200, details_hidden, data)
             return False
@@ -1178,9 +1092,7 @@ class T(unittest.TestCase):
                 return True  # pragma: no cover
 
             data["hidden_size"] = self.app.w("dialog_crash_new").get_size()
-            data["hidden_resizable"] = self.app.w(
-                "dialog_crash_new"
-            ).get_resizable()
+            data["hidden_resizable"] = self.app.w("dialog_crash_new").get_resizable()
             Gtk.main_quit()
             return False
 
@@ -1213,8 +1125,7 @@ class T(unittest.TestCase):
         # unicode arguments
         GLib.timeout_add(self.POLLING_INTERVAL_MS, close, 0)
         self.app.ui_info_message(
-            b"title \xe2\x99\xaa".decode("UTF-8"),
-            b"text \xe2\x99\xaa".decode("UTF-8"),
+            b"title \xe2\x99\xaa".decode("UTF-8"), b"text \xe2\x99\xaa".decode("UTF-8")
         )
 
         # with URLs
@@ -1262,9 +1173,7 @@ class T(unittest.TestCase):
         for url in urls:
             with self.subTest(url=url):
                 self.assertEqual(
-                    apport_gtk.text_to_markup(
-                        f"Contact them via {url} for help."
-                    ),
+                    apport_gtk.text_to_markup(f"Contact them via {url} for help."),
                     f'Contact them via <a href="{url}">{url}</a> for help.',
                 )
 
