@@ -9,6 +9,10 @@
 # Free Software Foundation; either version 2 of the License, or (at your
 # option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
 # the full text of the license.
+
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import os
 import shutil
 import tempfile
@@ -39,10 +43,9 @@ else:
     MainUserInterface = None
 
 
-@unittest.skipIf(
-    PYQT5_IMPORT_ERROR, f"PyQt/PyKDE not available: {PYQT5_IMPORT_ERROR}"
-)
+@unittest.skipIf(PYQT5_IMPORT_ERROR, f"PyQt/PyKDE not available: {PYQT5_IMPORT_ERROR}")
 class T(unittest.TestCase):
+    # pylint: disable=missing-class-docstring,missing-function-docstring
     COLLECTING_DIALOG = unittest.mock.call(
         str(apport_kde_path.parent),
         "Collecting Problem Information",
@@ -379,9 +382,7 @@ class T(unittest.TestCase):
         self.assertFalse(self.app.dialog.closed_button.isVisible())
         self.assertTrue(self.app.dialog.ignore_future_problems.isVisible())
         self.assertTrue(
-            str(self.app.dialog.ignore_future_problems.text()).endswith(
-                "of this type"
-            )
+            str(self.app.dialog.ignore_future_problems.text()).endswith("of this type")
         )
 
     def test_apport_bug_package_layout(self):
@@ -403,8 +404,7 @@ class T(unittest.TestCase):
         self.app.ui_present_report_details(True)
         self.assertEqual(self.app.dialog.windowTitle(), self.distro.split()[0])
         self.assertEqual(
-            self.app.dialog.heading.text(),
-            _("Send problem report to the developers?"),
+            self.app.dialog.heading.text(), _("Send problem report to the developers?")
         )
         self.assertFalse(self.app.dialog.text.isVisible())
         self.assertFalse(self.app.dialog.send_error_report.isVisible())
@@ -495,12 +495,9 @@ class T(unittest.TestCase):
     @unittest.mock.patch.object(
         MainUserInterface, "open_url", unittest.mock.MagicMock()
     )
+    @unittest.mock.patch("apport.report.Report.add_gdb_info", unittest.mock.MagicMock())
     @unittest.mock.patch(
-        "apport.report.Report.add_gdb_info", unittest.mock.MagicMock()
-    )
-    @unittest.mock.patch(
-        "apport.fileutils.allowed_to_report",
-        unittest.mock.MagicMock(return_value=True),
+        "apport.fileutils.allowed_to_report", unittest.mock.MagicMock(return_value=True)
     )
     def test_1_crash_nodetails(self):
         """Crash report without showing details"""
@@ -513,9 +510,7 @@ class T(unittest.TestCase):
             QTimer.singleShot(1000, cont)  # pragma: no cover
 
         QTimer.singleShot(1000, cont)
-        with wrap_object(
-            apport_kde.ProgressDialog, "__init__"
-        ) as progress_dialog:
+        with wrap_object(apport_kde.ProgressDialog, "__init__") as progress_dialog:
             self.app.run_crash(self.app.report_file)
 
         # we should have reported one crash
@@ -539,12 +534,9 @@ class T(unittest.TestCase):
     @unittest.mock.patch.object(
         MainUserInterface, "open_url", unittest.mock.MagicMock()
     )
+    @unittest.mock.patch("apport.report.Report.add_gdb_info", unittest.mock.MagicMock())
     @unittest.mock.patch(
-        "apport.report.Report.add_gdb_info", unittest.mock.MagicMock()
-    )
-    @unittest.mock.patch(
-        "apport.fileutils.allowed_to_report",
-        unittest.mock.MagicMock(return_value=True),
+        "apport.fileutils.allowed_to_report", unittest.mock.MagicMock(return_value=True)
     )
     def test_1_crash_details(self):
         """Crash report with showing details"""
@@ -572,9 +564,7 @@ class T(unittest.TestCase):
             QTimer.singleShot(200, cont)  # pragma: no cover
 
         QTimer.singleShot(200, show_details)
-        with wrap_object(
-            apport_kde.ProgressDialog, "__init__"
-        ) as progress_dialog:
+        with wrap_object(apport_kde.ProgressDialog, "__init__") as progress_dialog:
             self.app.run_crash(self.app.report_file)
 
         # we should have reported one crash
@@ -596,12 +586,9 @@ class T(unittest.TestCase):
     @unittest.mock.patch.object(
         MainUserInterface, "open_url", unittest.mock.MagicMock()
     )
+    @unittest.mock.patch("apport.report.Report.add_gdb_info", unittest.mock.MagicMock())
     @unittest.mock.patch(
-        "apport.report.Report.add_gdb_info", unittest.mock.MagicMock()
-    )
-    @unittest.mock.patch(
-        "apport.fileutils.allowed_to_report",
-        unittest.mock.MagicMock(return_value=True),
+        "apport.fileutils.allowed_to_report", unittest.mock.MagicMock(return_value=True)
     )
     def test_1_crash_noaccept(self):
         """Crash report with non-accepting crash DB"""
@@ -615,9 +602,7 @@ class T(unittest.TestCase):
 
         QTimer.singleShot(1000, cont)
         self.app.crashdb.options["problem_types"] = ["bug"]
-        with wrap_object(
-            apport_kde.ProgressDialog, "__init__"
-        ) as progress_dialog:
+        with wrap_object(apport_kde.ProgressDialog, "__init__") as progress_dialog:
             self.app.run_crash(self.app.report_file)
 
         # we should not have reported the crash
@@ -675,9 +660,7 @@ class T(unittest.TestCase):
         self.assertEqual(
             self.app.report["SourcePackage"], apport.packaging.get_source(pkg)
         )
-        self.assertEqual(
-            self.app.report["Package"], "%s (not installed)" % pkg
-        )
+        self.assertEqual(self.app.report["Package"], f"{pkg} (not installed)")
 
     @unittest.mock.patch.object(
         MainUserInterface, "open_url", unittest.mock.MagicMock()
@@ -736,7 +719,7 @@ class T(unittest.TestCase):
 
         # create source package hook, as otherwise there is nothing to collect
         with open(
-            os.path.join(self.hook_dir, "source_%s.py" % source_pkg),
+            os.path.join(self.hook_dir, f"source_{source_pkg}.py"),
             "w",
             encoding="utf-8",
         ) as f:
