@@ -1,3 +1,5 @@
+"""Unit tests for the apport.hookutils module."""
+
 import re
 import subprocess
 import time
@@ -7,7 +9,10 @@ import unittest.mock
 import apport.hookutils
 
 
-class T(unittest.TestCase):
+class TestHookutils(unittest.TestCase):
+    # pylint: disable=missing-function-docstring
+    """Test apport.hookutils module."""
+
     @unittest.mock.patch("apport.hookutils.root_command_output")
     def test_attach_dmesg(self, root_command_output_mock):
         """attach_dmesg()"""
@@ -27,9 +32,7 @@ class T(unittest.TestCase):
         self.assertEqual(report["CurrentDmesg"], "existingcurrent")
 
     @unittest.mock.patch("subprocess.run")
-    @unittest.mock.patch(
-        "os.path.exists", unittest.mock.MagicMock(return_value=True)
-    )
+    @unittest.mock.patch("os.path.exists", unittest.mock.MagicMock(return_value=True))
     def test_attach_journal_errors_with_date(self, run_mock):
         run_mock.return_value = subprocess.CompletedProcess(
             args=None, returncode=0, stdout=b"journalctl output", stderr=b""
@@ -51,9 +54,7 @@ class T(unittest.TestCase):
         )
 
     @unittest.mock.patch("subprocess.run")
-    @unittest.mock.patch(
-        "os.path.exists", unittest.mock.MagicMock(return_value=True)
-    )
+    @unittest.mock.patch("os.path.exists", unittest.mock.MagicMock(return_value=True))
     def test_attach_journal_errors_without_date(self, run_mock):
         run_mock.return_value = subprocess.CompletedProcess(
             args=None, returncode=0, stdout=b"journalctl output", stderr=b""
@@ -72,12 +73,9 @@ class T(unittest.TestCase):
 
     def test_path_to_key(self):
         """Transform a file path to a valid report key."""
+        self.assertEqual(apport.hookutils.path_to_key("simple.txt"), "simple.txt")
         self.assertEqual(
-            apport.hookutils.path_to_key("simple.txt"), "simple.txt"
-        )
-        self.assertEqual(
-            apport.hookutils.path_to_key("path/with/dirs.txt"),
-            "path.with.dirs.txt",
+            apport.hookutils.path_to_key("path/with/dirs.txt"), "path.with.dirs.txt"
         )
         self.assertEqual(
             apport.hookutils.path_to_key('/funny:characters!& ".txt'),
@@ -85,36 +83,26 @@ class T(unittest.TestCase):
         )
 
     @unittest.mock.patch("subprocess.Popen")
-    @unittest.mock.patch(
-        "os.path.exists", unittest.mock.MagicMock(return_value=True)
-    )
+    @unittest.mock.patch("os.path.exists", unittest.mock.MagicMock(return_value=True))
     def test_recent_syslog_journald_cmd(self, popen_mock):
-        class SkipPopen(Exception):
+        class _SkipPopen(Exception):
             pass
 
-        popen_mock.side_effect = SkipPopen
+        popen_mock.side_effect = _SkipPopen
 
         cmd = ["journalctl", "--quiet", "-b", "-a"]
         cmd_system_only = cmd + ["--system"]
 
-        with self.assertRaises(SkipPopen):
+        with self.assertRaises(_SkipPopen):
             apport.hookutils.recent_syslog(re.compile("."))
-        popen_mock.assert_called_once_with(
-            cmd_system_only, stdout=unittest.mock.ANY
-        )
+        popen_mock.assert_called_once_with(cmd_system_only, stdout=unittest.mock.ANY)
 
         popen_mock.reset_mock()
-        with self.assertRaises(SkipPopen):
-            apport.hookutils.recent_syslog(
-                re.compile("."), journald_only_system=True
-            )
-        popen_mock.assert_called_once_with(
-            cmd_system_only, stdout=unittest.mock.ANY
-        )
+        with self.assertRaises(_SkipPopen):
+            apport.hookutils.recent_syslog(re.compile("."), journald_only_system=True)
+        popen_mock.assert_called_once_with(cmd_system_only, stdout=unittest.mock.ANY)
 
         popen_mock.reset_mock()
-        with self.assertRaises(SkipPopen):
-            apport.hookutils.recent_syslog(
-                re.compile("."), journald_only_system=False
-            )
+        with self.assertRaises(_SkipPopen):
+            apport.hookutils.recent_syslog(re.compile("."), journald_only_system=False)
         popen_mock.assert_called_once_with(cmd, stdout=unittest.mock.ANY)
