@@ -1,3 +1,8 @@
+"""Unit tests for the problem_report module."""
+
+# TODO: Address following pylint complaints
+# pylint: disable=invalid-name
+
 import email
 import io
 import locale
@@ -10,7 +15,9 @@ import problem_report
 bin_data = b"ABABABABAB\0\0\0Z\x01\x02"
 
 
-class T(unittest.TestCase):
+class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
+    """Unit tests for the problem_report module."""
+
     def test_add_tags(self):
         """Test ProblemReport.add_tags()."""
         report = problem_report.ProblemReport()
@@ -88,17 +95,15 @@ class T(unittest.TestCase):
         self.assertRaises(ValueError, pr.__setitem__, "a b", "1")
         self.assertRaises(TypeError, pr.__setitem__, "a", 1)
         self.assertRaises(TypeError, pr.__setitem__, "a", (1,))
-        self.assertRaises(
-            TypeError, pr.__setitem__, "a", ("/tmp/nonexistant", "")
-        )
+        self.assertRaises(TypeError, pr.__setitem__, "a", ("/tmp/nonexistent", ""))
         self.assertRaises(
             TypeError,
             pr.__setitem__,
             "a",
-            ("/tmp/nonexistant", False, 0, True, "bogus"),
+            ("/tmp/nonexistent", False, 0, True, "bogus"),
         )
-        self.assertRaises(TypeError, pr.__setitem__, "a", ["/tmp/nonexistant"])
-        self.assertRaises(KeyError, pr.__getitem__, "Nonexistant")
+        self.assertRaises(TypeError, pr.__setitem__, "a", ["/tmp/nonexistent"])
+        self.assertRaises(KeyError, pr.__getitem__, "Nonexistent")
 
     def test_write(self):
         """write() and proper formatting."""
@@ -361,9 +366,7 @@ class T(unittest.TestCase):
         pr.load(io.BytesIO(bin_report), binary="compressed")
         self.assertEqual(pr.has_removed_fields(), False)
         self.assertEqual(len(pr["File"]), 31)
-        self.assertEqual(
-            pr["File"].get_value(), b"AB" * 10 + b"\0" * 10 + b"Z"
-        )
+        self.assertEqual(pr["File"].get_value(), b"AB" * 10 + b"\0" * 10 + b"Z")
         out = io.BytesIO()
         pr["File"].write(out)
         out.seek(0)
@@ -441,17 +444,15 @@ class T(unittest.TestCase):
         pr["SimpleLineEnd"] = "bar\n"
         pr["TwoLine"] = "first\nsecond\n"
         pr["InlineMargin"] = "first\nsecond\nthird\nfourth\nfifth\n"
-        pr[
-            "Multiline"
-        ] = " foo   bar\nbaz\n  blip  \nline4\nline♥5!!\nłıµ€ ⅝\n"
+        pr["Multiline"] = " foo   bar\nbaz\n  blip  \nline4\nline♥5!!\nłıµ€ ⅝\n"
 
         # still small enough for inline text
         pr["Largeline"] = "A" * 999
-        pr["LargeMultiline"] = "A" * 120 + "\n" + "B" * 90
+        pr["LargeMultiline"] = f"{'A' * 120}\n{'B' * 90}"
 
         # too big for inline text, these become attachments
         pr["Hugeline"] = "A" * 10000
-        pr["HugeMultiline"] = "A" * 900 + "\n" + "B" * 900 + "\n" + "C" * 900
+        pr["HugeMultiline"] = f"{'A' * 900}\n{'B' * 900}\n{'C' * 900}"
         out = io.BytesIO()
         pr.write_mime(out)
         out.seek(0)
@@ -514,9 +515,7 @@ class T(unittest.TestCase):
         self.assertEqual(parts[3].get_content_type(), "text/plain")
         self.assertEqual(parts[3].get_content_charset(), "utf-8")
         self.assertEqual(parts[3].get_filename(), "Hugeline.txt")
-        self.assertEqual(
-            parts[3].get_payload(decode=True), pr["Hugeline"].encode()
-        )
+        self.assertEqual(parts[3].get_payload(decode=True), pr["Hugeline"].encode())
 
         # fifth part should be the Multiline: field as attachment
         self.assertTrue(not parts[4].is_multipart())
@@ -541,9 +540,7 @@ class T(unittest.TestCase):
         pr["Simple"] = "bar"
         pr["TwoLine"] = "first\nsecond\n"
         out = io.BytesIO()
-        pr.write_mime(
-            out, extra_headers={"Greeting": "hello world", "Foo": "Bar"}
-        )
+        pr.write_mime(out, extra_headers={"Greeting": "hello world", "Foo": "Bar"})
         out.seek(0)
 
         msg = email.message_from_binary_file(out)
